import 'dart:math';

class ChartMaxAndInterval {
  late num maxY;
  late num interval;

  ChartMaxAndInterval() {
    maxY = 1;
    interval = 1;
  }
}

typedef AmountCondition = num Function(dynamic item);

class ChartCalculateUtils {
  static ChartMaxAndInterval calculateChart<T>(List<T> statics, AmountCondition condition, num minMaxY, num minInterval, {int factor = 1}) {
    ChartMaxAndInterval ret = ChartMaxAndInterval();
    for(T item in statics) {
      num value = condition(item);
      if(value > ret.maxY) {
        ret.maxY = value;
      }
    }

    int count = (minMaxY / minInterval).ceil();
    ret.maxY = max(ret.maxY, minMaxY);

    ret.interval = (ret.maxY / count);

    ret.interval = roundUp(ret.interval.ceil(), factor);
    ret.maxY = ret.interval * count;

    return ret;
  }

  static int roundUp(int number, int factor) {
    if (factor < 1) throw RangeError.range(factor, 1, null, "factor");
    number += factor - 1;
    return number - (number % factor);
  }
}