// ignore_for_file: avoid_print

import 'package:common_utils/common_utils.dart';
import 'package:flutter/material.dart';

class DateRangeStr {
  String startTime;
  String endTime;

  DateRangeStr({required this.startTime, required this.endTime});
}

abstract class DateFormatterUtils {
  ///
  
  static DateRangeStr formatterDatePickerStr(String? timeRange, {String? format}) {
    format = format ?? DateFormats.full;
    DateRangeStr result = DateRangeStr(startTime: "", endTime: "");
    try {
      if (timeRange != null && timeRange.isNotEmpty && timeRange.split(":").length == 2) {
        int? _iStart = int.tryParse(timeRange.split(":")[0]);
        if (_iStart != null) {
          result.startTime = DateUtil.formatDate(DateTime.fromMillisecondsSinceEpoch(_iStart), format: format);
        }
        int? _iEnd = int.tryParse(timeRange.split(":")[1]);
        if (_iEnd != null) {
          DateTime _dEnd = DateTime.fromMillisecondsSinceEpoch(_iEnd);
          _dEnd = _dEnd.add(const Duration(hours: 23, minutes: 59, seconds: 59));
          result.endTime = DateUtil.formatDate(_dEnd, format: format);
        }
      }
    } catch (error) {
      print(error.toString());
    }
    return result;
  }

  static String formatDateTimeRange(DateTimeRange? dateTimeRange, {String? format}) {
    format = format ?? DateFormats.y_mo_d;
    return DateUtil.formatDate(dateTimeRange?.start, format: format) + "~" + DateUtil.formatDate(dateTimeRange?.end, format: format);
  }

  static String formatDateTime(DateTime? dateTime, {String? format}) {
    format = format ?? DateFormats.y_mo_d;
    return DateUtil.formatDate(dateTime, format: format);
  }

  //1.当天展示时分
  //2.非当天展示月日
  //3.非当年展示年月日
  static String formatterTime(String time) {
    try {
      DateTime dt = DateTime.now();
      DateTime? pt = DateTime.tryParse(time);
      if (pt != null) {
        if (pt.day == dt.day) {
          return DateUtil.formatDate(pt, format: DateFormats.h_m);
        } else if (pt.year == dt.year) {
          return DateUtil.formatDate(pt, format: DateFormats.mo_d);
        } else {
          return DateUtil.formatDate(pt, format: DateFormats.y_mo_d);
        }
      }
    } catch (error) {
      print(error.toString());
    }
    return "";
  }

  static String formatterChatTime(String? lastTime, String sendTime) {
    try {
      DateTime? dt = DateTime.tryParse(sendTime);
      DateTime? pt = DateTime.tryParse(lastTime ?? "");

      if (pt == null || dt == null) {
        if (dt != null) {
          return DateUtil.formatDate(dt, format: DateFormats.y_mo_d_h_m);
        }
        return "";
      }

      if (pt.day == dt.day) {
        if (dt.difference(pt).inMinutes > 3) {
          return DateUtil.formatDate(pt, format: DateFormats.h_m);
        } else {
          return "";
        }
      } else if (pt.year == dt.year) {
        return DateUtil.formatDate(pt, format: DateFormats.mo_d_h_m);
      } else {
        return DateUtil.formatDate(pt, format: DateFormats.y_mo_d_h_m);
      }
    } catch (error) {
      print(error.toString());
    }
    return "";
  }

  static bool isInTimeRange(String beginHm, String endHm) {
    DateTime nowTime = DateTime.now();
    beginHm = DateUtil.formatDate(nowTime, format: DateFormats.y_mo_d) + " " + beginHm;
    endHm = DateUtil.formatDate(nowTime, format: DateFormats.y_mo_d) + " " + endHm;
    DateTime start = DateTime.parse(beginHm);
    DateTime end = DateTime.parse(endHm);
    if (start.compareTo(end) == 1 || start.isAtSameMomentAs(end)) {
      if (nowTime.isAfter(start) || nowTime.isBefore(end)) {
        return true;
      }
    } else {
      if (nowTime.isAfter(start) && nowTime.isBefore(end)) {
        return true;
      }
    }
    return false;
  }
}
