import 'dart:io';

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';

class ImageUtils {
  static ImageProvider getAssetImage(String name, {AssetBundle? bundle, String? package}) {
    return AssetImage(getImagePath(name), bundle: bundle, package: package);
  }

  static String getImagePath(String name) {
    if(name.startsWith("assets")) {
      return name;
    }
    return 'assets/images/$name'; 
  }

  static ImageProvider getImageProvider(String imageUrl, {String holderImg = 'assets/common/images/img_fail.png'}) {
    if (imageUrl.isEmpty) {
      return AssetImage(getImagePath(holderImg));
    } else if (imageUrl.startsWith('http')) {
      return CachedNetworkImageProvider(imageUrl);
    } else {
      return FileImage(File(imageUrl));
    }
  }

  static Widget getNetworkImage(String imageUrl, {String holderImg = 'assets/common/images/img_fail.png', BoxFit? fit,}) {
    if (imageUrl.isEmpty) {
      return Image.asset(getImagePath(holderImg), fit: fit,);
    }
    return CachedNetworkImage(
        fit: fit,
        imageUrl: imageUrl,
        progressIndicatorBuilder: (context, url, downloadProgress) => 
                SizedBox(width: 30, height: 30, child: Center(child: CircularProgressIndicator(value: downloadProgress.progress))),
        errorWidget: (context, url, error) => const Icon(Icons.error),
     );
  }
}