class ValidUtils {
  ///

  static String validKMile(int? startK, int? endMile, int? limitStartK, int? limitStartMile, int? limitEndK, int? limitEndMile) {
    if (startK == null || endMile == null) {
      return "桩号为空";
    }
    if (startK == -1 || endMile == -1) {
      return "请输入桩号";
    }
    if (startK < 0 || endMile < 0) {
      return "桩号格式错误";
    }
    if (endMile.toString().isEmpty || endMile.toString().length > 3) {
      return "终点只能填3位数";
    }
    if (limitStartK != null && limitStartMile != null) {
      if (limitStartK * 1000 + limitStartMile > (startK * 1000 + endMile)) {
        return "低于养护段范围：K" + limitStartK.toString() + "~" + limitStartMile.toString();
      }
    }
    if (limitEndK != null && limitEndMile != null) {
      if (limitEndK * 1000 + limitEndMile < (startK * 1000 + endMile)) {
        return "超出养护段范围：K" + limitEndK.toString() + "~" + limitEndK.toString();
      }
    }
    return "";
  }

  static String validLatitudeLongitude(String? latitude, String? longitude) {
    if (latitude == null || latitude.isEmpty) {
      return "纬度为空";
    }
    if (longitude == null || longitude.isEmpty) {
      return "经度为空";
    }
    double? dlat = double.tryParse(latitude);
    if (dlat == null) {
      return "纬度格式错误";
    }
    if (dlat < -90 || dlat > 90) {
      return "纬度范围错误";
    }

    double? dlong = double.tryParse(longitude);
    if (dlong == null) {
      return "经度格式错误";
    }
    if (dlong < -180 || dlong > 180) {
      return "经度范围错误";
    }

    return "";
  }

  static String validNum(String? num) {
    if (num == null || num.isEmpty) {
      return "为空";
    }
    if (int.tryParse(num) == null) {
      return "只能为数字";
    }
    return "";
  }

  static bool validCarNumber(String? plate) {
    try {
      if (plate == null || plate.isEmpty) {
        return true;
      }
      const _regExp = r"^(([京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼使领][A-Z](([0-9]{5}[DF])|([DF]([A-HJ-NP-Z0-9])[0-9]{4})))|([京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼使领][A-Z][A-HJ-NP-Z0-9]{4}[A-HJ-NP-Z0-9挂学警港澳使领]))$";
      RegExp reg = RegExp(_regExp);
      return reg.hasMatch(plate);
    } catch (error) {
      return false;
    }
  }

  static String getAge(DateTime brt) {
    int age = 0;
    DateTime dateTime = DateTime.now();
    if (dateTime.isBefore(brt)) {
      //出生日期晚于当前时间，无法计算
      return '出生日期不能超过当前时间';
    }
    int yearNow = dateTime.year; //当前年份
    int monthNow = dateTime.month; //当前月份
    int dayOfMonthNow = dateTime.day; //当前日期

    int yearBirth = brt.year;
    int monthBirth = brt.month;
    int dayOfMonthBirth = brt.day;
    age = yearNow - yearBirth; //计算整岁数
    if (monthNow <= monthBirth) {
      if (monthNow == monthBirth) {
        if (dayOfMonthNow < dayOfMonthBirth) age--; //当前日期在生日之前，年龄减一
      } else {
        age--; //当前月份在生日之前，年龄减一
      }
    }
    return age.toString();
  }

  static bool isEmpty(dynamic str) {
    if(str == null) {
      return true;
    }
    if(str is String) {
      return str.isEmpty;
    }
    return false;
  }
}
