import 'package:flutter/material.dart';
import 'package:tengits_common/widgets/src/bruno_calendar.dart';
import 'package:tengits_common/widgets/src/empty_widget.dart';
import 'common_bottom_sheet.dart';
import 'date_picker_bottom_sheet.dart';
import 'date_range_bottom_sheet.dart';
import 'multi_bottom_sheet.dart';
import 'multi_column_bottom_sheet.dart';
import 'single_bottom_sheet.dart';

typedef TitleTransformer<T> = String Function(T value, int? index);
typedef IsSelected<T> = bool Function(T value, int? index);
typedef IsDisable<T> = bool Function(T value);
typedef ValueChange<T> = void Function(T value, int? index);

class BottomSheetSingleResult<T> {
  T item;
  int? index;
  BottomSheetSingleResult(this.item, this.index);
}

Future<BottomSheetSingleResult<T>?> showSingleBottomSheetDialog<T>(
  BuildContext context,
  String title,
  List<T> items, {
  IsSelected<T>? isSelected,
  TitleTransformer<T>? titleTransformer,
  IsDisable<T>? isDisable,
}) {
  return showModalBottomSheet<BottomSheetSingleResult<T>>(
      isScrollControlled: true,
      context: context,
      builder: (BuildContext context) {
        return SingleSelectList<T>(
          title: title,
          listData: items,
          titleTransformer: titleTransformer,
          isSelected: isSelected,
          isDisable: isDisable,
        );
      });
}

Future<List<T>?> showMultiBottomSheetDialog<T>(
  BuildContext context,
  String title,
  List<T> items, {
  IsSelected<T>? isSelected,
  required TitleTransformer<T> titleTransformer,
}) {
  return showModalBottomSheet(
      context: context,
      isScrollControlled: true,
      builder: (BuildContext context) {
        return MulitiBottomSheet<T>(
          title: title,
          listData: items,
          titleTransformer: titleTransformer,
          isSelected: isSelected,
        );
      });
}

Future showDateBottomSheetDialog(BuildContext context, String title, {DateTime? startTime, DateTime? endTime, SelectMode? selectMode}) {
  return showModalBottomSheet(
      context: context,
      isScrollControlled: true,
      builder: (BuildContext context) {
        return SingleChildScrollView(
          child: DateRangeBottomSheet(
            title: title,
            initialStartTime: startTime,
            initialEndTime: endTime,
            selectMode: selectMode,
          ),
        );
      });
}

Future showDatePickerBottomSheetDialog(BuildContext context, String title, {DateTime? startTime}) {
  return showModalBottomSheet(
      context: context,
      isScrollControlled: true,
      builder: (BuildContext context) {
        return DatePickerBottomSheet(title: title, initialStartTime: startTime);
      });
}

Future showGridListBottomSheetDialog(BuildContext context, String title, List<Widget> buttons, {Widget? header, String descText = ""}) {
  return showModalBottomSheet(
      context: context,
      builder: (context) {
        return CommonBottomSheet(
          title: title,
          padding: 16,
          contentWidget: buttons.isNotEmpty
              ? Column(
                  children: [
                    Offstage(
                      offstage: header == null,
                      child: header,
                    ),
                    GridView.count(
                      childAspectRatio: 106 / 130,
                      crossAxisCount: 3,
                      children: buttons,
                      shrinkWrap: true,
                    ),
                  ],
                )
              : TNoDataWidget(
                  title: descText,
                ),
          expanded: descText.isNotEmpty,
        );
      });
}

Future showMultiColumnBottomSheetDialog(BuildContext context, String title, List<Map<String, dynamic>> items, String parentIdKey, int parentId,
    {int? selected, String? itemName, String? compareId, Function(List<Map<String, dynamic>> items, List<int> ids)? onSelected}) {
  return showModalBottomSheet(
      context: context,
      isScrollControlled: true,
      builder: (context) {
        return MultiColumnBottomSheet(
          title: title,
          items: items,
          parentIdKey: parentIdKey,
          parentId: parentId,
          itemName: itemName,
          compareId: compareId,
          selected: selected,
          onSelected: onSelected,
        );
      });
}
