import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class CommonBottomSheet<T> extends StatelessWidget {
  const CommonBottomSheet({
    Key? key,
    required this.title,
    required this.contentWidget,
    this.operatorWidget,
    this.padding = 16,
    this.expanded = false,
  }) : super(key: key);
  final T title;
  final Widget contentWidget;
  final Widget? operatorWidget;
  final double padding;
  final bool expanded;

  @override
  Widget build(BuildContext context) {
    return Container(
        constraints: BoxConstraints(minHeight: 340.h, maxHeight: 620.h),
        padding: EdgeInsets.only(left: padding.w, right: padding.w, bottom: MediaQuery.of(context).padding.bottom),
        decoration: const BoxDecoration(color: Colors.white),
        child: Column(mainAxisSize: MainAxisSize.min, crossAxisAlignment: CrossAxisAlignment.start, children: [
          Container(
            height: 62.h,
            alignment: Alignment.centerLeft,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Expanded(
                    child: title is String
                        ? Text(
                            title as String,
                            style: TextStyle(color: const Color(0xff323233), fontSize: 20.sp, height: 1.h),
                          )
                        : title as Widget),
                IconButton(
                    onPressed: () {
                      Navigator.of(context).pop(null);
                    },
                    padding: EdgeInsets.only(left: 8.w),
                    icon: Icon(
                      Icons.close,
                      size: 24.r,
                      color: const Color(0xff969799),
                    )),
              ],
            ),
          ),
          Container(
            margin: EdgeInsets.only(bottom: padding.h),
            height: 1.h,
            color: const Color(0xffF7F8FA),
          ),
          expanded ? Expanded(child: contentWidget) : contentWidget,
          operatorWidget ?? const SizedBox.shrink(),
        ]));
  }
}
