import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/utils/src/loading_toast_util.dart';
import 'package:tengits_common/widgets/src/bruno_calendar.dart';
import 'package:tengits_common/widgets/src/button.dart';
import 'package:tengits_common/widgets/src/card.dart';

import 'common_bottom_sheet.dart';

class DateRangeBottomSheet extends StatefulWidget {
  const DateRangeBottomSheet({Key? key, required this.title, this.initialStartTime, this.initialEndTime, this.selectMode}) : super(key: key);

  final String title;
  final DateTime? initialStartTime;
  final DateTime? initialEndTime;
  final SelectMode? selectMode;

  @override
  State<DateRangeBottomSheet> createState() => _DateRangeBottomSheetState();
}

class _DateRangeBottomSheetState extends State<DateRangeBottomSheet> {
  DateTime? startTime;
  DateTime? endTime;

  bool isReset = true;

  final LocalKey key1 = UniqueKey();
  final LocalKey key2 = UniqueKey();

  @override
  void initState() {
    super.initState();
    startTime = widget.initialStartTime;
    endTime = widget.initialEndTime;
    isReset = true;
  }

  @override
  Widget build(BuildContext context) {
    return CommonBottomSheet(
      title: widget.title,
      contentWidget: Container(
        constraints: BoxConstraints(maxHeight: 400.h),
        child: SingleChildScrollView(
          physics: const AlwaysScrollableScrollPhysics(),
          child: TBrnCalendarView(
            key: isReset ? key1 : key2,
            displayMode: DisplayMode.month,
            selectMode: widget.selectMode ?? SelectMode.range,
            initStartSelectedDate: startTime,
            initEndSelectedDate: endTime,
            initDisplayDate: startTime ?? DateTime.now(),
            dateChange: (DateTime datetime) {
              setState(() {
                startTime = datetime;
                endTime = datetime;
                isReset = false;
              });
            },
            rangeDateChange: (range) {
              setState(() {
                startTime = range.start;
                endTime = range.end;
                isReset = false;
              });
            },
          ),
        ),
      ),
      operatorWidget: ButtonOperatorCard(buttons: [
        OutBorderButton(
            onPress: () {
              setState(() {
                startTime = widget.initialStartTime;
                endTime = widget.initialEndTime;
                isReset = true;
              });
            },
            title: "重置"),
        PrimaryButton(
            onPress: () {
              if (widget.selectMode == SelectMode.single) {
                if (startTime == null) {
                  TLoadingUtils.showToast("请先选择时间");
                  return;
                }
                Navigator.of(context).pop(DateTimeRange(start: startTime!, end: startTime!));
              } else if (widget.selectMode == SelectMode.range) {
                if (startTime == null || endTime == null) {
                  TLoadingUtils.showToast("请先选择时间范围");
                  return;
                }
                Navigator.of(context).pop(DateTimeRange(start: startTime!, end: endTime!));
              }
            },
            title: "确定")
      ]),
    );
  }
}
