import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:loading_more_list/loading_more_list.dart';
import 'package:tengits_common/widgets/src/bottom_sheet/bottom_sheet.dart';
import 'package:tengits_common/widgets/src/bottom_sheet/common_bottom_sheet.dart';
import 'package:tengits_common/widgets/src/loading_more_status_widget.dart';
import 'package:tengits_common/widgets/src/search_bar.dart';
import 'single_bottom_sheet.dart';

class LoadingMoreSelectList<T> extends StatefulWidget {
  const LoadingMoreSelectList(
      {Key? key, required this.title, required this.listRepository, this.isSelected, this.titleTransformer, this.hintText, this.isDisable, this.showSearch = true, this.onSelect})
      : super(key: key);
  final String title;
  final Function(T)? onSelect;
  final IsSelected<T>? isSelected;
  final TitleTransformer<T>? titleTransformer;
  final String? hintText;
  final bool showSearch;
  final LoadingMoreWithSearch<T> listRepository;
  final IsDisable<T>? isDisable;

  @override
  State<LoadingMoreSelectList> createState() => _LoadingMoreSelectListState<T>();
}

class _LoadingMoreSelectListState<T> extends State<LoadingMoreSelectList<T>> {
  late T selectItems;

  final normalTextStyle = const TextStyle(color: Color(0xff323233), fontSize: 16);
  final selectedTextStyle = const TextStyle(color: Color(0xff1989FA), fontSize: 16);
  final disableTextStyle = const TextStyle(color: Color(0xffC8C9CC), fontSize: 16);

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return CommonBottomSheet(
        title: widget.title,
        contentWidget: Container(
          constraints: const BoxConstraints(maxHeight: 460),
          child: Column(
            children: [
              if (widget.showSearch)
                SearchBar(
                  hint: widget.hintText ?? "搜索",
                  onSearch: (text) {
                    widget.listRepository.searchData(text);
                  },
                ),
              Expanded(
                child: RefreshIndicator(
                  onRefresh: () async {
                    widget.listRepository.refresh();
                  },
                  child: LoadingMoreList<T>(
                    ListConfig(
                        itemBuilder: (context, item, index) {
                          bool isSelected = widget.isSelected?.call(item, index) ?? false;
                          String strTitle = widget.titleTransformer?.call(item, index) ?? item as String;
                          bool isDisabled = widget.isDisable?.call(item) ?? false;
                          return SingleSelectItem(
                            title: strTitle,
                            isSelected: isSelected,
                            isDisabled: isDisabled,
                            buildItem: (selected, title) {
                              return Container(
                                padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 10),
                                decoration: selected
                                    ? BoxDecoration(
                                        color: const Color(
                                          0xffE6F2FE,
                                        ),
                                        borderRadius: BorderRadius.circular(8))
                                    : const BoxDecoration(),
                                child: Text(
                                  title,
                                  style: selected ? selectedTextStyle : (isDisabled ? disableTextStyle : normalTextStyle),
                                ),
                              );
                            },
                            onSelected: () {
                              setState(() {
                                selectItems = item;
                                widget.onSelect?.call(selectItems);
                              });
                            },
                          );
                        },
                        sourceList: widget.listRepository,
                        indicatorBuilder: (BuildContext context, IndicatorStatus status) {
                          return buildLoadingMoreListIndicator(context, status, widget.listRepository);
                        },
                        physics: const AlwaysScrollableScrollPhysics(),
                        padding: const EdgeInsets.symmetric(vertical: 8),
                        lastChildLayoutType: LastChildLayoutType.fullCrossAxisExtent,
                        autoRefresh: true),
                  ),
                ),
              ),
            ],
          ),
        ));
  }
}

abstract class LoadingMoreWithSearch<T> extends LoadingMoreBase<T> {
  Future searchData(String text);
}

class LoadingMoreSelectList1<T> extends StatefulWidget {
  const LoadingMoreSelectList1({
    Key? key,
    required this.title,
    required this.listRepository,
    this.isSelected,
    this.titleTransformer,
    this.hintText,
    this.isDisable,
    this.showSearch = true,
    this.onSelect,
    this.wrapValues,
    this.wrapSelectValue,
  }) : super(key: key);
  final String title;
  final Function(T)? onSelect;
  final IsSelected<T>? isSelected;
  final TitleTransformer<T>? titleTransformer;
  final String? hintText;
  final bool showSearch;
  final LoadingMoreWithSearch<T> listRepository;
  final IsDisable<T>? isDisable;
  final List<String>? wrapValues;
  final Function(String)? wrapSelectValue;

  @override
  State<LoadingMoreSelectList1> createState() => _LoadingMoreSelectListState1<T>();
}

class _LoadingMoreSelectListState1<T> extends State<LoadingMoreSelectList1<T>> {
  late T selectItems;
  late String wrapSelectValue = "";

  final normalTextStyle = TextStyle(color: const Color(0xff323233), fontSize: 16.sp);
  final selectedTextStyle = TextStyle(color: const Color(0xff1989FA), fontSize: 16.sp);
  final disableTextStyle = TextStyle(color: const Color(0xffC8C9CC), fontSize: 16.sp);

  int wrapSelectedIndex = -1;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: 8.w, vertical: 16.h),
      child: Column(children: [
        if (widget.showSearch)
          SearchBar(
            hint: widget.hintText ?? "搜索",
            onSearch: (text) {
              widget.listRepository.searchData(text);
            },
          ),
        // TLWrapChoiceBox<String>(
        //   "",
        //   items: widget.wrapValues ?? [],
        //   titleTransformer: (String item) {
        //     return item;
        //   },
        //   isSelected: (String item) {
        //     return wrapSelectValue == item;
        //   },
        //   onValueChange: (String item, int index) {
        //     setState(() {
        //       wrapSelectValue = item;
        //       widget.wrapSelectValue?.call(wrapSelectValue);
        //     });
        //   },
        //   type: TLWrapChoiceBoxType.wrapSpaceBetween,
        //   padding: EdgeInsets.symmetric(horizontal: 12.w, vertical: 15.h),
        // ),
        Container(
          constraints: BoxConstraints(maxHeight: 145.h),
          child: GridView.count(
            //设置滚动方向
            scrollDirection: Axis.vertical,
            //设置列数
            crossAxisCount: 3,
            //设置内边距
            padding: EdgeInsets.all(10.r),
            //设置横向间距
            crossAxisSpacing: 10.w,
            //设置主轴间距
            mainAxisSpacing: 10.h,
            //设置宽高的比例，GridView的子组件直接设置宽高没有反应，可以通过childAspectRatio修改宽高。
            childAspectRatio: 3.0,
            //
            physics: const AlwaysScrollableScrollPhysics(),
            //内容适配，默认为false
            shrinkWrap: true,
            children: _getWidgets(widget.wrapValues ?? []),
          ),
        ),
        Expanded(
          child: RefreshIndicator(
            onRefresh: () async {
              widget.listRepository.refresh();
            },
            child: LoadingMoreList<T>(
              ListConfig(
                  itemBuilder: (context, item, index) {
                    bool isSelected = widget.isSelected?.call(item, index) ?? false;
                    String strTitle = widget.titleTransformer?.call(item, index) ?? item as String;
                    bool isDisabled = widget.isDisable?.call(item) ?? false;
                    return SingleSelectItem(
                      title: strTitle,
                      isSelected: isSelected,
                      isDisabled: isDisabled,
                      buildItem: (selected, title) {
                        return Container(
                          padding: EdgeInsets.symmetric(horizontal: 12.h, vertical: 10.w),
                          decoration: selected
                              ? BoxDecoration(
                                  color: const Color(
                                    0xffE6F2FE,
                                  ),
                                  borderRadius: BorderRadius.circular(8))
                              : const BoxDecoration(),
                          child: Text(
                            title,
                            style: selected ? selectedTextStyle : (isDisabled ? disableTextStyle : normalTextStyle),
                          ),
                        );
                      },
                      onSelected: () {
                        setState(() {
                          selectItems = item;
                          widget.onSelect?.call(selectItems);
                        });
                      },
                    );
                  },
                  sourceList: widget.listRepository,
                  indicatorBuilder: (BuildContext context, IndicatorStatus status) {
                    return buildLoadingMoreListIndicator(context, status, widget.listRepository);
                  },
                  physics: const AlwaysScrollableScrollPhysics(),
                  padding: EdgeInsets.symmetric(vertical: 8.w),
                  lastChildLayoutType: LastChildLayoutType.fullCrossAxisExtent,
                  autoRefresh: true),
            ),
          ),
        ),
      ]),
    );
  }

  List<Widget> _getWidgets(List<String> listData) {
    List<Widget> list = [];
    for (var index = 0; index < listData.length; index++) {
      String text = listData[index];
      list.add(
        InkWell(
          child: Container(
            alignment: Alignment.center,
            decoration: BoxDecoration(color: wrapSelectedIndex == index ? const Color(0xFF1989FA) : const Color(0xFFF8F8F8), borderRadius: BorderRadius.circular(4.r)),
            child: Text(text, style: TextStyle(color: wrapSelectedIndex == index ? const Color(0xFFFFFFFF) : const Color(0xFF969799), fontSize: 14.sp)),
          ),
          onTap: () {
            setState(() {
              if (wrapSelectedIndex != index) {
                wrapSelectedIndex = index;
                widget.wrapSelectValue?.call(text);
              } else {
                wrapSelectedIndex = -1;
                widget.wrapSelectValue?.call("");
              }
            });
          },
        ),
      );
    }
    return list;
  }
}
