import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/widgets/src/button.dart';
import 'package:tengits_common/widgets/src/card.dart';

import 'bottom_sheet.dart';
import 'common_bottom_sheet.dart';

class MulitiBottomSheet<T> extends StatefulWidget {
  const MulitiBottomSheet({Key? key, required this.title, required this.listData, this.isSelected, this.titleTransformer}) : super(key: key);
  final String title;
  final List<T> listData;
  final IsSelected<T>? isSelected;
  final TitleTransformer<T>? titleTransformer;

  @override
  State<MulitiBottomSheet> createState() => _MultiBottomSheetState<T>();
}

class _MultiBean<T> {
  T data;
  bool select;

  _MultiBean({required this.data, required this.select});
}

class _MultiBottomSheetState<T> extends State<MulitiBottomSheet<T>> {
  final List<_MultiBean<T>> beanItems = [];

  @override
  void initState() {
    super.initState();
    for (int i = 0; i < widget.listData.length; i++) {
      T data = widget.listData[i];
      beanItems.add(_MultiBean(data: data, select: widget.isSelected?.call(data, i) ?? false));
    }
  }

  @override
  Widget build(BuildContext context) {
    return CommonBottomSheet(
      title: widget.title,
      contentWidget: Expanded(
        child: ListView.builder(
          itemBuilder: (context, index) {
            return MultiSelectItemCheckBox<T>(
              title: widget.titleTransformer?.call(widget.listData[index], index) ?? widget.listData[index] as String,
              bean: beanItems[index],
            );
          },
          itemCount: beanItems.length,
          shrinkWrap: true,
        ),
      ),
      operatorWidget: ButtonOperatorCard(
        buttons: [
          PrimaryButton(
            onPress: () {
              Navigator.of(context).pop(beanItems.where((element) => element.select).map((e) => e.data).toList());
            },
            title: '提交',
          )
        ],
      ),
    );
  }
}

class MultiSelectItemCheckBox<T> extends StatefulWidget {
  final String title;
  final _MultiBean<T> bean;

  const MultiSelectItemCheckBox({Key? key, required this.title, required this.bean}) : super(key: key);

  @override
  State<MultiSelectItemCheckBox> createState() => _MultiSelectItemCheckBoxState<T>();
}

class _MultiSelectItemCheckBoxState<T> extends State<MultiSelectItemCheckBox<T>> {
  final normalTextStyle = const TextStyle(color: Color(0xff969799), fontSize: 16);
  final selectedTextStyle = const TextStyle(color: Color(0xff323233), fontSize: 16);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () {
        setState(() {
          widget.bean.select = !widget.bean.select;
        });
      },
      child: Ink(
        child: Container(
          margin: const EdgeInsets.only(bottom: 0),
          padding: EdgeInsets.symmetric(horizontal: 8.w, vertical: 16.h),
          decoration: const BoxDecoration(color: Colors.white, border: Border(bottom: BorderSide(color: Color(0xffF7F8FA)))),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            children: [
              Expanded(
                child: Text(widget.title, style: widget.bean.select ? selectedTextStyle : normalTextStyle),
              ),
              SizedBox(
                width: 24.w,
              ),
              SizedBox(
                width: 24.w,
                height: 24.h,
                child: Checkbox(
                    shape: const CircleBorder(),
                    fillColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
                      const Set<MaterialState> interactiveStates = <MaterialState>{
                        MaterialState.pressed,
                        MaterialState.hovered,
                        MaterialState.focused,
                      };
                      if (states.contains(MaterialState.disabled)) {
                        return ThemeData.from(colorScheme: const ColorScheme.light()).disabledColor;
                      }
                      if (states.contains(MaterialState.selected)) {
                        return const Color(0xff2B6BD8);
                      }
                      if (states.any(interactiveStates.contains)) {
                        return Colors.red;
                      }
                      // 最终返回
                      return const Color(0xffC8C9CC);
                    }),
                    value: widget.bean.select,
                    onChanged: (value) {
                      setState(() {
                        widget.bean.select = !widget.bean.select;
                      });
                    }),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
