import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import 'common_bottom_sheet.dart';

class MultiColumnBottomSheet extends StatefulWidget {
  const MultiColumnBottomSheet({
    Key? key,
    required this.title,
    required this.items,
    required this.parentIdKey,
    required this.parentId,
    this.itemName,
    this.compareId,
    this.selected,
    this.onSelected,
  }) : super(key: key);

  final String title;
  final List<Map<String, dynamic>> items;
  final int? selected;
  final String? itemName;
  final String? compareId;
  final String parentIdKey;
  final int parentId;
  final Function(List<Map<String, dynamic>> items, List<int> ids)? onSelected;

  @override
  State<MultiColumnBottomSheet> createState() => _MultiColumnBottomSheetState();
}

class _MultiColumnBottomSheetState extends State<MultiColumnBottomSheet> {
  int currentIndex = 0;
  int? selected;
  Map<int, Node> map = {};
  List<Node> tree = [];

  List<Node> list0 = [];
  List<Node> list1 = [];
  List<Node> list2 = [];

  @override
  void initState() {
    super.initState();
    List<Node> treeTemp = [];
    for (var item in widget.items) {
      treeTemp.add(Node(object: item, parendId: item[widget.parentIdKey], members: [], nodeId: item[widget.compareId]));
    }
    for (var item in treeTemp) {
      map[item.nodeId] = item;
    }
    for (var item in treeTemp) {
      int parentId = item.parendId;
      Node? node;
      if (parentId != widget.parentId) {
        node = map[parentId];
      }
      if (node == null) {
        tree.add(item);
      } else {
        List childs = node.members;
        childs.add(item);
      }
    }

    list0 = tree.where((element) => element.parendId == widget.parentId).toList();
    selected = widget.selected;
    List<int> ids = getSelectedParendIds().reversed.toList();
    if (ids.length > 1) {
      list1 = map[ids[0]]!.members;
    }
    if (ids.length > 2) {
      list2 = map[ids[1]]!.members;
      currentIndex = 1;
    }
  }

  @override
  Widget build(BuildContext context) {
    return CommonBottomSheet(
      padding: 0,
      title: getTitle(),
      contentWidget: Container(
        padding: const EdgeInsets.only(top: 16),
        constraints: BoxConstraints(maxHeight: 370.h, maxWidth: MediaQuery.of(context).size.width),
        child: renderTree(),
      ),
    );
  }

  getTitle() {
    if (currentIndex == 0) {
      return Padding(
        padding: const EdgeInsets.only(left: 16),
        child: Text(
          widget.title,
          style: const TextStyle(color: Color(0xff323233), fontSize: 20, height: 1),
        ),
      );
    } else {
      return Row(
        mainAxisSize: MainAxisSize.max,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          IconButton(
              onPressed: () {
                setState(() {
                  currentIndex = 0;
                });
              },
              padding: const EdgeInsets.only(left: 0),
              icon: const Icon(
                Icons.arrow_back_ios,
                size: 24,
                color: Color(0xff969799),
              )),
          Text(widget.title, style: const TextStyle(color: Color(0xff323233), fontSize: 20, height: 1.3)),
        ],
      );
    }
  }

  Widget renderTree() {
    if (currentIndex == 0) {
      return renderLevelOne();
    } else {
      return renderLevelTwo();
    }
  }

  Widget renderLevelOne() {
    return Row(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Expanded(
          flex: 2,
          child: Container(
            decoration: const BoxDecoration(color: Color(0xfff2f3f5)),
            child: ListView.builder(
              itemBuilder: (context, index) {
                return ParentSelectItem(
                  title: list0[index].object[widget.itemName],
                  isSelected: isSected(list0[index]),
                  onSelected: () {
                    setState(() {
                      selected = list0[index].nodeId;
                      if (list0[index].members.isNotEmpty) {
                        list1 = list0[index].members;
                      } else {
                        widget.onSelected?.call(getSelectedItems(), getSelectedParendIds());
                        Navigator.of(context).pop();
                      }
                    });
                  },
                );
              },
              itemCount: list0.length,
              shrinkWrap: true,
            ),
          ),
        ),
        Expanded(
          flex: 3,
          child: ListView.builder(
            padding: const EdgeInsets.symmetric(horizontal: 16),
            itemBuilder: (context, index) {
              return SubSelectItem(
                title: list1[index].object[widget.itemName],
                isSelected: isSected(list1[index]),
                onSelected: () {
                  setState(() {
                    selected = list1[index].nodeId;
                    var members = list1[index].members;
                    if (members.isNotEmpty) {
                      currentIndex = 1;
                      list2 = members;
                    } else {
                      widget.onSelected?.call(getSelectedItems(), getSelectedParendIds());
                      Navigator.of(context).pop();
                    }
                  });
                },
              );
            },
            itemCount: list1.length,
            shrinkWrap: true,
          ),
        )
      ],
    );
  }

  Widget renderLevelTwo() {
    return ListView.builder(
      padding: const EdgeInsets.symmetric(horizontal: 16),
      itemBuilder: (context, index) {
        return SubSelectItem(
          title: list2[index].object[widget.itemName],
          isSelected: isSected(list2[index]),
          onSelected: () {
            setState(() {
              selected = list2[index].nodeId;
              widget.onSelected?.call(getSelectedItems(), getSelectedParendIds());
              Navigator.of(context).pop();
            });
          },
        );
      },
      itemCount: list2.length,
      shrinkWrap: true,
    );
  }

  bool isSected(Node node) {
    List<int> result = getSelectedParendIds();
    return result.contains(node.nodeId);
  }

  List<int> getSelectedParendIds() {
    List<int> result = [];
    Node? node = map[selected];
    while (node != null) {
      result.add(node.nodeId);
      if (node.parendId == widget.parentId) {
        break;
      }
      node = map[node.parendId];
    }
    return result;
  }

  List<Map<String, dynamic>> getSelectedItems() {
    List<Map<String, dynamic>> result = [];
    Node? node = map[selected];
    while (node != null) {
      result.add(node.object);
      if (node.parendId == widget.parentId) {
        break;
      }
      node = map[node.parendId];
    }
    return result;
  }
}

class ParentSelectItem extends StatelessWidget {
  const ParentSelectItem({Key? key, required this.title, required this.isSelected, this.onSelected}) : super(key: key);

  final String title;
  final bool isSelected;
  final Function()? onSelected;

  final normalTextStyle = const TextStyle(color: Color(0xff323233), fontSize: 16);
  final selectedTextStyle = const TextStyle(color: Color(0xff1989FA), fontSize: 16);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () {
        if (!isSelected) {
          onSelected?.call();
        }
      },
      child: Ink(
        child: Container(
          padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 11),
          decoration: isSelected ? const BoxDecoration(color: Colors.white) : const BoxDecoration(),
          child: Align(
            alignment: Alignment.centerLeft,
            child: Text(
              title,
              style: isSelected ? selectedTextStyle : normalTextStyle,
            ),
          ),
        ),
      ),
    );
  }
}

class SubSelectItem extends StatelessWidget {
  SubSelectItem({Key? key, required this.title, required this.isSelected, this.onSelected}) : super(key: key);

  final String title;
  final bool isSelected;
  final Function()? onSelected;

  final selectedDecoration = BoxDecoration(
      color: const Color(
        0xffE6F2FE,
      ),
      borderRadius: BorderRadius.circular(8.r));
  final normalTextStyle = const TextStyle(color: Color(0xff323233), fontSize: 16);
  final selectedTextStyle = const TextStyle(color: Color(0xff1989FA), fontSize: 16);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () {
        onSelected?.call();
      },
      child: Ink(
        child: Container(
          padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 11),
          decoration: isSelected ? selectedDecoration : const BoxDecoration(),
          child: Align(
            alignment: Alignment.centerLeft,
            child: Text(
              title,
              style: isSelected ? selectedTextStyle : normalTextStyle,
            ),
          ),
        ),
      ),
    );
  }
}

class Node {
  dynamic object;
  int parendId;
  int nodeId;
  List<Node> members;

  Node({required this.object, required this.parendId, required this.nodeId, required this.members});
}
