import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import 'bottom_sheet.dart';
import 'common_bottom_sheet.dart';


class SingleSelectList<T> extends StatelessWidget {
  const SingleSelectList({Key? key, required this.title, required this.listData, this.isSelected, this.titleTransformer, this.isDisable, this.isCenter = true}) : super(key: key);
  final String title;
  final List<T> listData;
  final bool isCenter;
  final IsSelected<T>? isSelected;
  final TitleTransformer<T>? titleTransformer;
  final IsDisable<T>? isDisable;

  @override
  Widget build(BuildContext context) {
    return CommonBottomSheet(
      title: title,
      contentWidget: Container(
        constraints: BoxConstraints(maxHeight: 370.h),
        child: ListView.builder(
          itemBuilder: ((context, index) {
            bool isDisabled = isDisable?.call(listData[index]) ?? false;
            bool isSelect = isSelected?.call(listData[index], index) ?? false;
            String strTitle = titleTransformer?.call(listData[index], index) ?? listData[index] as String;
            return SingleSelectItem(
              title: strTitle,
              isSelected: isSelect,
              isDisabled: isDisabled,
              onSelected: () {
                Navigator.of(context).pop(BottomSheetSingleResult(listData[index], index));
              },
            );
          }),
          itemCount: listData.length,
          shrinkWrap: true,
        ),
      ),
    );
  }
}

class SingleSelectItem extends StatelessWidget {
  SingleSelectItem({Key? key, required this.title, required this.isSelected, this.onSelected, this.buildItem, this.isCenter = true, this.isDisabled = false}) : super(key: key);

  final String title;
  final bool isSelected;
  final Function()? onSelected;
  final Widget Function(bool selected, String title)? buildItem;
  final bool isCenter;
  final bool isDisabled;

  final selectedDecoration = BoxDecoration(
      color: const Color(
        0xffE6F2FE,
      ),
      borderRadius: BorderRadius.circular(4.r));
  final normalTextStyle = const TextStyle(color: Color(0xff323233), fontSize: 16);
  final selectedTextStyle = const TextStyle(color: Color(0xff1989FA), fontSize: 16);
  final disableTextStyle = const TextStyle(color: Color(0xffC8C9CC), fontSize: 16);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () {
        if (!isDisabled && !isSelected) {
          onSelected?.call();
        }
      },
      child: Ink(
        child: buildItem == null
            ? Container(
                constraints: BoxConstraints(
                  minHeight: 46.h,
                ),
                decoration: isSelected ? selectedDecoration : const BoxDecoration(),
                child: isCenter
                    ? Center(
                        child: Text(
                          title,
                          style: isSelected ? selectedTextStyle : (isDisabled ? disableTextStyle : normalTextStyle),
                        ),
                      )
                    : Text(
                        title,
                        style: isSelected ? selectedTextStyle : (isDisabled ? disableTextStyle : normalTextStyle),
                      ),
              )
            : buildItem!(isSelected, title),
      ),
    );
  }
}
