import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import 'bottom_sheet/bottom_sheet.dart';
import 'textFlag.dart';

class ButtonSelectDrawer<T> extends StatelessWidget {
  const ButtonSelectDrawer({
    Key? key,
    required this.title,
    required this.listData,
    this.isSelected,
    this.titleTransformer,
    this.isDisable,
    this.onRefresh,
    this.onValueChange,
  }) : super(key: key);

  final String title;
  final List<T> listData;
  final IsSelected<T>? isSelected;
  final TitleTransformer<T>? titleTransformer;
  final IsDisable<T>? isDisable;
  final RefreshCallback? onRefresh;
  final ValueChange<T>? onValueChange;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 300.w,
      height: double.infinity,
      padding: EdgeInsets.only(top: MediaQuery.of(context).padding.top, bottom: MediaQuery.of(context).padding.bottom),
      decoration: BoxDecoration(color: Colors.white, borderRadius: BorderRadius.horizontal(right: Radius.circular(8.r))),
      child: Column(children: [
        SizedBox(
          height: 12.h,
        ),
        TextFlag(
          title: title,
          style: TextStyle(color: Colors.black, fontSize: 24.sp, fontWeight: FontWeight.w500),
          imageWidth: 12.w,
          imageHeight: 40.h,
        ),
        SizedBox(
          height: 24.h,
        ),
        SeparationLine(color: const Color(0xffA2CFFC)),
        Expanded(
          child: RefreshIndicator(
            onRefresh: () async {
              onRefresh?.call();
            },
            child: SingleChildScrollView(
              physics: const AlwaysScrollableScrollPhysics(),
              padding: EdgeInsets.symmetric(horizontal: 28.w, vertical: 0),
              child: ListView.builder(
                physics: const NeverScrollableScrollPhysics(),
                padding: EdgeInsets.symmetric(vertical: 24.h),
                itemBuilder: (context, index) {
                  bool isSelect = isSelected?.call(listData[index], index) ?? false;
                  return InkWell(
                    onTap: () {
                      onValueChange?.call(listData[index], index);
                      Navigator.of(context).pop();
                    },
                    child: Ink(
                      child: Container(
                        margin: EdgeInsets.symmetric(vertical: 8.h),
                        constraints: BoxConstraints(minWidth: 244.w, maxWidth: 244.w, minHeight: 48.h),
                        decoration: BoxDecoration(borderRadius: BorderRadius.all(Radius.circular(4.r)), color: isSelect ? const Color(0xffE6F2FE) : const Color(0xffF7F8FA)),
                        child: Center(
                          child: Text(
                            titleTransformer?.call(listData[index], index) ?? listData[index] as String,
                            style: TextStyle(color: isSelect ? const Color(0xff1989FA) : const Color(0xff323233), fontSize: 16.sp),
                          ),
                        ),
                      ),
                    ),
                  );
                },
                shrinkWrap: true,
                itemCount: listData.length,
              ),
            ),
          ),
        ),
      ]),
    );
  }
}
