import 'package:flutter/material.dart';
import 'package:flutter_pickers/pickers.dart';
import 'package:flutter_pickers/time_picker/model/date_mode.dart';
import 'package:flutter_pickers/time_picker/model/pduration.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/widgets/src/calendar_date_picker_route.dart';
import 'bruno_calendar.dart';

class TLCalendar extends StatefulWidget {
  const TLCalendar(
    this.title, {
    Key? key,
    this.style,
    this.padding,
    this.startTime,
    this.endTime,
    this.selectMode = SelectMode.single,
    this.dateChange,
    this.rangeDateChange,
    this.minDate,
    this.maxDate,
  }) : super(key: key);

  @override
  State<TLCalendar> createState() => _TLCalendarState();

  final String title;
  final TextStyle? style;
  final EdgeInsetsGeometry? padding;
  final DateTime? startTime;
  final DateTime? endTime;
  final SelectMode selectMode;
  final Function(DateTime datetime)? dateChange;
  final Function(DateTimeRange dateTimeRange)? rangeDateChange;
  final DateTime? minDate;

  /// 日历日期选择范围最大值
  ///
  /// 默认 `DateTime(2100)`
  final DateTime? maxDate;
}

GlobalKey<_TLCalendarState> _calendarKey = GlobalKey<_TLCalendarState>();
GlobalKey<_TLCalendarState> get calendarKey => _calendarKey;

class _TLCalendarState extends State<TLCalendar> {
  //

  // dateChangeChoiceSure() {
  //   if (startTime != null) {
  //     widget.dateChange?.call(startTime!);
  //   }
  // }
  // rangeDateChoiceSure() {
  //   if (startTime != null && endTime != null) {
  //     widget.rangeDateChange?.call(DateTimeRange(start: startTime!, end: endTime!));
  //   }
  // }

  dateReset() {
    setState(() {
      startTime = widget.startTime;
      endTime = widget.endTime;
      isReset = true;
    });
    widget.dateChange?.call(widget.startTime ?? DateTime.now());
  }

  @override
  void initState() {
    super.initState();
    startTime = widget.startTime;
    endTime = widget.endTime;
    isReset = true;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: widget.padding ?? EdgeInsets.zero,
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          widget.title.isEmpty
              ? const SizedBox.shrink()
              : Padding(
                  padding: EdgeInsets.symmetric(
                    vertical: 8.h,
                  ),
                  child: Text(
                    widget.title,
                    style: widget.style ??
                        TextStyle(
                          color: Colors.black,
                          fontSize: 16.sp,
                          fontWeight: FontWeight.w500,
                        ),
                  ),
                ),
          TBrnCalendarView(
            key: isReset ? key1 : key2,
            displayMode: DisplayMode.month,
            selectMode: widget.selectMode,
            initStartSelectedDate: startTime,
            initEndSelectedDate: endTime,
            minDate: widget.minDate,
            maxDate: widget.maxDate,
            dateChange: (DateTime datetime) {
              setState(() {
                startTime = datetime;
                isReset = false;
              });
              widget.dateChange?.call(datetime);
            },
            rangeDateChange: (DateTimeRange dateTimeRange) {
              setState(() {
                startTime = dateTimeRange.start;
                endTime = dateTimeRange.end;
                isReset = false;
              });
              widget.rangeDateChange?.call(dateTimeRange);
            },
          ),
        ],
      ),
    );
  }

  DateTime? startTime;
  DateTime? endTime;
  bool isReset = true;
  LocalKey key1 = UniqueKey();
  LocalKey key2 = UniqueKey();
}

class TLPickers {
  static void showDatePicker(BuildContext context, {DateMode mode = DateMode.YMDHMS, PDuration? maxDate, String normalTime = "", Function(String time)? onConfirm}) {
    Pickers.showDatePicker(
      context,
      selectDate: PDuration.parse(DateTime.tryParse(normalTime) ?? DateTime.now()),
      mode: mode,
      maxDate: maxDate,
      onConfirm: (PDuration p) {
        String time = "";
        if (mode == DateMode.YMDHMS) {
          time = p.year.toString() +
              "-" +
              p.month.toString().padLeft(2, "0") +
              "-" +
              p.day.toString().padLeft(2, "0") +
              " " +
              p.hour.toString().padLeft(2, "0") +
              ":" +
              p.minute.toString().padLeft(2, "0") +
              ":" +
              p.second.toString().padLeft(2, "0");
        } else if (mode == DateMode.YMDHM) {
          time = p.year.toString() +
              "-" +
              p.month.toString().padLeft(2, "0") +
              "-" +
              p.day.toString().padLeft(2, "0") +
              " " +
              p.hour.toString().padLeft(2, "0") +
              ":" +
              p.minute.toString().padLeft(2, "0");
        } else if (mode == DateMode.YMD) {
          time = p.year.toString() + "-" + p.month.toString().padLeft(2, "0") + "-" + p.day.toString().padLeft(2, "0");
        }
        onConfirm?.call(time);
      },
    );
  }

  static void showTDatePicker(BuildContext context, {DateMode mode = DateMode.YMDHMS, PDuration? maxDate, String normalTime = "", Function(String time)? onConfirm}) {
    TPickers.showTDatePicker(
      context,
      selectDate: PDuration.parse(DateTime.tryParse(normalTime) ?? DateTime.now()),
      mode: mode,
      maxDate: maxDate,
      onConfirm: (PDuration p) {
        String time = "";
        if (mode == DateMode.YMDHMS) {
          time = p.year.toString() +
              "-" +
              p.month.toString().padLeft(2, "0") +
              "-" +
              p.day.toString().padLeft(2, "0") +
              " " +
              p.hour.toString().padLeft(2, "0") +
              ":" +
              p.minute.toString().padLeft(2, "0") +
              ":" +
              p.second.toString().padLeft(2, "0");
        } else if (mode == DateMode.YMDHM) {
          time = p.year.toString() +
              "-" +
              p.month.toString().padLeft(2, "0") +
              "-" +
              p.day.toString().padLeft(2, "0") +
              " " +
              p.hour.toString().padLeft(2, "0") +
              ":" +
              p.minute.toString().padLeft(2, "0");
        } else if (mode == DateMode.YMD) {
          time = p.year.toString() + "-" + p.month.toString().padLeft(2, "0") + "-" + p.day.toString().padLeft(2, "0");
        }
        onConfirm?.call(time);
      },
    );
  }

  static void showAddressPicker(BuildContext context, {String normalAddress = "", Function(String address)? onConfirm}) {
    if (normalAddress.isEmpty) {
      normalAddress = '湖北省/武汉市';
    }
    // Pickers.showAddressPicker(
    //   context,
    //   initProvince: normalAddress.split('/').first,
    //   initCity: normalAddress.split('/').last,
    //   addAllItem: false,
    //   onConfirm: (String initProvince, String initCity, String? initTown) {
    //     onConfirm?.call([initProvince, initCity].join('/'));
    //   },
    // );
    Map<String, List<String>> multiData = {};
    for (Map typeItem in cityOptions) {
      multiData[typeItem["value"]] = typeItem["children"].map<String>((e) => e["value"] as String).toList();
    }
    Pickers.showMultiLinkPicker(
      context,
      data: multiData,
      selectData: [normalAddress.split('/').first, normalAddress.split('/').last],
      columeNum: 2,
      onConfirm: (list1, list2) {
        onConfirm?.call([list1[0], list1[1]].join('/'));
      },
    );
  }

  static String getAddressFromCardNumber(String cardNumber) {
    String preCardNumber = cardNumber.substring(0, 6);
    for (Map typeItem in cityOptions) {
      for (Map city in typeItem["children"]) {
        if (city["LCode"] != null && preCardNumber.contains(city["LCode"])) {
          return "${typeItem["value"]}/${city["value"]}";
        }
      }
    }
    return "";
  }

  static String getAddress(String plateNo) {
    for (Map typeItem in cityOptions) {
      for (Map city in typeItem["children"]) {
        if (city["code"] != null && plateNo.contains(city["code"])) {
          return "${typeItem["value"]}/${city["value"]}";
        }
      }
    }
    return "";
  }
}

const cityOptions = [
  {
    "children": [
      {"label": "武汉市", "value": "武汉市", "Pcode": "鄂", "code": "鄂A", "LCode": "4201"},
      {"label": "黄石市", "value": "黄石市", "Pcode": "鄂", "code": "鄂B", "LCode": "4202"},
      {"label": "十堰市", "value": "十堰市", "Pcode": "鄂", "code": "鄂C", "LCode": "4203"},
      {"label": "宜昌市", "value": "宜昌市", "Pcode": "鄂", "code": "鄂E", "LCode": "4205"},
      {"label": "襄阳市", "value": "襄阳市", "Pcode": "鄂", "code": "鄂F", "LCode": "4206"},
      {"label": "鄂州市", "value": "鄂州市", "Pcode": "鄂", "code": "鄂G", "LCode": "4207"},
      {"label": "荆门市", "value": "荆门市", "Pcode": "鄂", "code": "鄂H", "LCode": "4208"},
      {"label": "孝感市", "value": "孝感市", "Pcode": "鄂", "code": "鄂K", "LCode": "4209"},
      {"label": "荆州市", "value": "荆州市", "Pcode": "鄂", "code": "鄂D", "LCode": "4210"},
      {"label": "黄冈市", "value": "黄冈市", "Pcode": "鄂", "code": "鄂J", "LCode": "4211"},
      {"label": "咸宁市", "value": "咸宁市", "Pcode": "鄂", "code": "鄂L", "LCode": "4212"},
      {"label": "随州市", "value": "随州市", "Pcode": "鄂", "code": "鄂S", "LCode": "4213"},
      {"label": "恩施土家族苗族自治州", "value": "恩施土家族苗族自治州", "Pcode": "鄂", "code": "鄂Q", "LCode": "4228"},
      {"label": "仙桃市", "value": "仙桃市", "Pcode": "鄂", "code": "鄂M", "LCode": "429004"},
      {"label": "潜江市", "value": "潜江市", "Pcode": "鄂", "code": "鄂N", "LCode": "429005"},
      {"label": "天门市", "value": "天门市", "Pcode": "鄂", "code": "鄂R", "LCode": "429006"},
      {"label": "神农架林区", "value": "神农架林区", "Pcode": "鄂", "code": "鄂P", "LCode": "429021"}
    ],
    "label": "湖北省",
    "value": "湖北省",
    "Pcode": "鄂",
    "LCode": "42"
  },
  {
    "children": [
      {"label": "东城区", "value": "东城区", "Pcode": "京", "code": "京A", "LCode": "110101"},
      {"label": "西城区", "value": "西城区", "Pcode": "京", "code": "京B", "LCode": "110102"},
      {"label": "朝阳区", "value": "朝阳区", "Pcode": "京", "code": "京C", "LCode": "110105"},
      {"label": "丰台区", "value": "丰台区", "Pcode": "京", "code": "京D", "LCode": "110106"},
      {"label": "石景山区", "value": "石景山区", "Pcode": "京", "code": "京E", "LCode": "110107"},
      {"label": "海淀区", "value": "海淀区", "Pcode": "京", "code": "京F", "LCode": "110108"},
      {"label": "门头沟区", "value": "门头沟区", "Pcode": "京", "code": "京G", "LCode": "110109"},
      {"label": "房山区", "value": "房山区", "Pcode": "京", "code": "京H", "LCode": "110111"},
      {"label": "通州区", "value": "通州区", "Pcode": "京", "code": "京J", "LCode": "110112"},
      {"label": "顺义区", "value": "顺义区", "Pcode": "京", "code": "京K", "LCode": "110113"},
      {"label": "昌平区", "value": "昌平区", "Pcode": "京", "code": "京L", "LCode": "110114"},
      {"label": "大兴区", "value": "大兴区", "Pcode": "京", "code": "京M", "LCode": "110115"},
      {"label": "怀柔区", "value": "怀柔区", "Pcode": "京", "code": "京N", "LCode": "110116"},
      {"label": "平谷区", "value": "平谷区", "Pcode": "京", "code": "京P", "LCode": "110117"},
      {"label": "密云区", "value": "密云区", "Pcode": "京", "code": "京Q", "LCode": "110118"},
      {"label": "延庆区", "value": "延庆区", "Pcode": "京", "code": "京Y", "LCode": "110119"}
    ],
    "label": "北京市",
    "value": "北京市",
    "Pcode": "京",
    "LCode": "11"
  },
  {
    "children": [
      {"label": "黄浦区", "value": "黄浦区", "Pcode": "沪", "code": "沪A", "LCode": "310101"},
      {"label": "徐汇区", "value": "徐汇区", "Pcode": "沪", "code": "沪B", "LCode": "310104"},
      {"label": "长宁区", "value": "长宁区", "Pcode": "沪", "code": "沪C", "LCode": "310105"},
      {"label": "静安区", "value": "静安区", "Pcode": "沪", "code": "沪D", "LCode": "310106"},
      {"label": "普陀区", "value": "普陀区", "Pcode": "沪", "code": "沪E", "LCode": "310107"},
      {"label": "虹口区", "value": "虹口区", "Pcode": "沪", "code": "沪F", "LCode": "310109"},
      {"label": "杨浦区", "value": "杨浦区", "Pcode": "沪", "code": "沪G", "LCode": "310110"},
      {"label": "闵行区", "value": "闵行区", "Pcode": "沪", "code": "沪H", "LCode": "310112"},
      {"label": "宝山区", "value": "宝山区", "Pcode": "沪", "code": "沪J", "LCode": "230506"},
      {"label": "嘉定区", "value": "嘉定区", "Pcode": "沪", "code": "沪K", "LCode": "310114"},
      {"label": "浦东新区", "value": "浦东新区", "Pcode": "沪", "code": "沪L", "LCode": "310115"},
      {"label": "金山区", "value": "金山区", "Pcode": "沪", "code": "沪M", "LCode": "310116"},
      {"label": "松江区", "value": "松江区", "Pcode": "沪", "code": "沪N", "LCode": "310117"},
      {"label": "青浦区", "value": "青浦区", "Pcode": "沪", "code": "沪D", "LCode": "310118"},
      {"label": "奉贤区", "value": "奉贤区", "Pcode": "沪", "code": "沪E", "LCode": "310120"},
      {"label": "崇明区", "value": "崇明区", "Pcode": "沪", "code": "沪F", "LCode": "310151"}
    ],
    "label": "上海市",
    "value": "上海市",
    "Pcode": "沪",
    "LCode": "31"
  },
  {
    "children": [
      {"label": "昆明市", "value": "昆明市", "Pcode": "云", "code": "云A", "LCode": "5301"},
      {"label": "曲靖市", "value": "曲靖市", "Pcode": "云", "code": "云D", "LCode": "5303"},
      {"label": "玉溪市", "value": "玉溪市", "Pcode": "云", "code": "云F", "LCode": "5304"},
      {"label": "保山市", "value": "保山市", "Pcode": "云", "code": "云M", "LCode": "5305"},
      {"label": "昭通市", "value": "昭通市", "Pcode": "云", "code": "云C", "LCode": "5306"},
      {"label": "丽江市", "value": "丽江市", "Pcode": "云", "code": "云P", "LCode": "5307"},
      {"label": "普洱市", "value": "普洱市", "Pcode": "云", "code": "云J", "LCode": "5308"},
      {"label": "临沧市", "value": "临沧市", "Pcode": "云", "code": "云S", "LCode": "5309"},
      {"label": "楚雄彝族自治州", "value": "楚雄彝族自治州", "Pcode": "云", "code": "云E", "LCode": "5323"},
      {"label": "红河哈尼族彝族自治州", "value": "红河哈尼族彝族自治州", "Pcode": "云", "code": "云G", "LCode": "5325"},
      {"label": "文山壮族苗族自治州", "value": "文山壮族苗族自治州", "Pcode": "云", "code": "云H", "LCode": "5326"},
      {"label": "西双版纳傣族自治州", "value": "西双版纳傣族自治州", "Pcode": "云", "code": "云K", "LCode": "5328"},
      {"label": "大理白族自治州", "value": "大理白族自治州", "Pcode": "云", "code": "云L", "LCode": "5329"},
      {"label": "德宏傣族景颇族自治州", "value": "德宏傣族景颇族自治州", "Pcode": "云", "code": "云N", "LCode": "5331"},
      {"label": "怒江傈僳族自治州", "value": "怒江傈僳族自治州", "Pcode": "云", "code": "云Q", "LCode": "5333"},
      {"label": "迪庆藏族自治州", "value": "迪庆藏族自治州", "Pcode": "云", "code": "云R", "LCode": "5334"}
    ],
    "label": "云南省",
    "value": "云南省",
    "Pcode": "云",
    "LCode": "53"
  },
  {
    "children": [
      {"label": "呼和浩特市", "value": "呼和浩特市", "Pcode": "蒙", "code": "蒙A", "LCode": "1501"},
      {"label": "包头市", "value": "包头市", "Pcode": "蒙", "code": "蒙B", "LCode": "1502"},
      {"label": "乌海市", "value": "乌海市", "Pcode": "蒙", "code": "蒙C", "LCode": "1503"},
      {"label": "赤峰市", "value": "赤峰市", "Pcode": "蒙", "code": "蒙D", "LCode": "1504"},
      {"label": "通辽市", "value": "通辽市", "Pcode": "蒙", "code": "蒙G", "LCode": "1505"},
      {"label": "鄂尔多斯市", "value": "鄂尔多斯市", "Pcode": "蒙", "code": "蒙K", "LCode": "1506"},
      {"label": "呼伦贝尔市", "value": "呼伦贝尔市", "Pcode": "蒙", "code": "蒙E", "LCode": "1507"},
      {"label": "巴彦淖尔市", "value": "巴彦淖尔市", "Pcode": "蒙", "code": "蒙L", "LCode": "1508"},
      {"label": "乌兰察布市", "value": "乌兰察布市", "Pcode": "蒙", "code": "蒙J", "LCode": "1509"},
      {"label": "兴安盟", "value": "兴安盟", "Pcode": "蒙", "code": "蒙F", "LCode": "1522"},
      {"label": "锡林郭勒盟", "value": "锡林郭勒盟", "Pcode": "蒙", "code": "蒙H", "LCode": "1525"},
      {"label": "阿拉善盟", "value": "阿拉善盟", "Pcode": "蒙", "code": "蒙M", "LCode": "1529"}
    ],
    "label": "内蒙古自治区",
    "value": "内蒙古自治区",
    "Pcode": "蒙",
    "LCode": "15"
  },
  {
    "children": [
      {"label": "长春市", "value": "长春市", "Pcode": "吉", "code": "吉A", "LCode": "2201"},
      {"label": "吉林市", "value": "吉林市", "Pcode": "吉", "code": "吉B", "LCode": "2200"},
      {"label": "四平市", "value": "四平市", "Pcode": "吉", "code": "吉C", "LCode": "2203"},
      {"label": "辽源市", "value": "辽源市", "Pcode": "吉", "code": "吉D", "LCode": "2204"},
      {"label": "通化市", "value": "通化市", "Pcode": "吉", "code": "吉E", "LCode": "2205"},
      {"label": "白山市", "value": "白山市", "Pcode": "吉", "code": "吉F", "LCode": "2206"},
      {"label": "松原市", "value": "松原市", "Pcode": "吉", "code": "吉J", "LCode": "2207"},
      {"label": "白城市", "value": "白城市", "Pcode": "吉", "code": "吉G", "LCode": "2208"},
      {"label": "延边朝鲜族自治州", "value": "延边朝鲜族自治州", "Pcode": "吉", "code": "吉H", "LCode": "2224"}
    ],
    "label": "吉林省",
    "value": "吉林省",
    "Pcode": "吉",
    "LCode": "22"
  },
  {
    "children": [
      {"label": "成都市", "value": "成都市", "Pcode": "川", "code": "川A", "LCode": "5101"},
      {"label": "自贡市", "value": "自贡市", "Pcode": "川", "code": "川C", "LCode": "5103"},
      {"label": "攀枝花市", "value": "攀枝花市", "Pcode": "川", "code": "川D", "LCode": "5104"},
      {"label": "泸州市", "value": "泸州市", "Pcode": "川", "code": "川E", "LCode": "5105"},
      {"label": "德阳市", "value": "德阳市", "Pcode": "川", "code": "川F", "LCode": "5106"},
      {"label": "绵阳市", "value": "绵阳市", "Pcode": "川", "code": "川B", "LCode": "5107"},
      {"label": "广元市", "value": "广元市", "Pcode": "川", "code": "川H", "LCode": "5108"},
      {"label": "遂宁市", "value": "遂宁市", "Pcode": "川", "code": "川J", "LCode": "5109"},
      {"label": "内江市", "value": "内江市", "Pcode": "川", "code": "川K", "LCode": "5110"},
      {"label": "乐山市", "value": "乐山市", "Pcode": "川", "code": "川L", "LCode": "5111"},
      {"label": "南充市", "value": "南充市", "Pcode": "川", "code": "川R", "LCode": "5113"},
      {"label": "眉山市", "value": "眉山市", "Pcode": "川", "code": "川Z", "LCode": "5114"},
      {"label": "宜宾市", "value": "宜宾市", "Pcode": "川", "code": "川Q", "LCode": "5115"},
      {"label": "广安市", "value": "广安市", "Pcode": "川", "code": "川X", "LCode": "5116"},
      {"label": "达州市", "value": "达州市", "Pcode": "川", "code": "川S", "LCode": "5117"},
      {"label": "雅安市", "value": "雅安市", "Pcode": "川", "code": "川T", "LCode": "511800"},
      {"label": "巴中市", "value": "巴中市", "Pcode": "川", "code": "川Y", "LCode": "5119"},
      {"label": "资阳市", "value": "资阳市", "Pcode": "川", "code": "川M", "LCode": "5120"},
      {"label": "阿坝藏族羌族自治州", "value": "阿坝藏族羌族自治州", "Pcode": "川", "code": "川U", "LCode": "513200"},
      {"label": "甘孜藏族自治州", "value": "甘孜藏族自治州", "Pcode": "川", "code": "川V", "LCode": "513300"},
      {"label": "凉山彝族自治州", "value": "凉山彝族自治州", "Pcode": "川", "code": "川W", "LCode": "5134"}
    ],
    "label": "四川省",
    "value": "四川省",
    "Pcode": "川",
    "LCode": "51"
  },
  {
    "children": [
      {"label": "和平区", "value": "和平区", "Pcode": "津", "code": "津A", "LCode": "120101"},
      {"label": "河东区", "value": "河东区", "Pcode": "津", "code": "津B", "LCode": "120102"},
      {"label": "河西区", "value": "河西区", "Pcode": "津", "code": "津D", "LCode": "120103"},
      {"label": "南开区", "value": "南开区", "Pcode": "津", "code": "津E", "LCode": "120104"},
      {"label": "河北区", "value": "河北区", "Pcode": "津", "code": "津F", "LCode": "120105"},
      {"label": "红桥区", "value": "红桥区", "Pcode": "津", "code": "津G", "LCode": "120106"},
      {"label": "东丽区", "value": "东丽区", "Pcode": "津", "code": "津H", "LCode": "120110"},
      {"label": "西青区", "value": "西青区", "Pcode": "津", "code": "津J", "LCode": "120111"},
      {"label": "津南区", "value": "津南区", "Pcode": "津", "code": "津K", "LCode": "120112"},
      {"label": "北辰区", "value": "北辰区", "Pcode": "津", "code": "津L", "LCode": "120113"},
      {"label": "武清区", "value": "武清区", "Pcode": "津", "code": "津N", "LCode": "120114"},
      {"label": "宝坻区", "value": "宝坻区", "Pcode": "津", "code": "津P", "LCode": "120115"},
      {"label": "滨海新区", "value": "滨海新区", "Pcode": "津", "code": "津Q", "LCode": "120116"},
      {"label": "宁河区", "value": "宁河区", "Pcode": "津", "code": "津R", "LCode": "120117"},
      {"label": "静海区", "value": "静海区", "Pcode": "津", "code": "津A", "LCode": "120118"},
      {"label": "蓟州区", "value": "蓟州区", "Pcode": "津", "code": "津B", "LCode": "120119"}
    ],
    "label": "天津市",
    "value": "天津市",
    "Pcode": "津",
    "LCode": "12"
  },
  {
    "children": [
      {"label": "银川市", "value": "银川市", "Pcode": "宁", "code": "宁A", "LCode": "6401"},
      {"label": "石嘴山市", "value": "石嘴山市", "Pcode": "宁", "code": "宁B", "LCode": "6402"},
      {"label": "吴忠市", "value": "吴忠市", "Pcode": "宁", "code": "宁C", "LCode": "6403"},
      {"label": "固原市", "value": "固原市", "Pcode": "宁", "code": "宁D", "LCode": "6404"},
      {"label": "中卫市", "value": "中卫市", "Pcode": "宁", "code": "宁E", "LCode": "6405"}
    ],
    "label": "宁夏回族自治区",
    "value": "宁夏回族自治区",
    "Pcode": "宁",
    "LCode": "64"
  },
  {
    "children": [
      {"label": "合肥市", "value": "合肥市", "Pcode": "皖", "code": "皖A", "LCode": "3401"},
      {"label": "芜湖市", "value": "芜湖市", "Pcode": "皖", "code": "皖B", "LCode": "3402"},
      {"label": "蚌埠市", "value": "蚌埠市", "Pcode": "皖", "code": "皖C", "LCode": "3403"},
      {"label": "淮南市", "value": "淮南市", "Pcode": "皖", "code": "皖D", "LCode": "3404"},
      {"label": "马鞍山市", "value": "马鞍山市", "Pcode": "皖", "code": "皖E", "LCode": "3405"},
      {"label": "淮北市", "value": "淮北市", "Pcode": "皖", "code": "皖F", "LCode": "3406"},
      {"label": "铜陵市", "value": "铜陵市", "Pcode": "皖", "code": "皖G", "LCode": "3407"},
      {"label": "安庆市", "value": "安庆市", "Pcode": "皖", "code": "皖H", "LCode": "3408"},
      {"label": "黄山市", "value": "黄山市", "Pcode": "皖", "code": "皖J", "LCode": "3410"},
      {"label": "滁州市", "value": "滁州市", "Pcode": "皖", "code": "皖M", "LCode": "3411"},
      {"label": "阜阳市", "value": "阜阳市", "Pcode": "皖", "code": "皖K", "LCode": "3412"},
      {"label": "宿州市", "value": "宿州市", "Pcode": "皖", "code": "皖L", "LCode": "3413"},
      {"label": "六安市", "value": "六安市", "Pcode": "皖", "code": "皖N", "LCode": "3415"},
      {"label": "亳州市", "value": "亳州市", "Pcode": "皖", "code": "皖S", "LCode": "3416"},
      {"label": "池州市", "value": "池州市", "Pcode": "皖", "code": "皖R", "LCode": "3417"},
      {"label": "宣城市", "value": "宣城市", "Pcode": "皖", "code": "皖P", "LCode": "3418"}
    ],
    "label": "安徽省",
    "value": "安徽省",
    "Pcode": "皖",
    "LCode": "34"
  },
  {
    "children": [
      {"label": "济南市", "value": "济南市", "Pcode": "鲁", "code": "鲁A", "LCode": "3701"},
      {"label": "青岛市", "value": "青岛市", "Pcode": "鲁", "code": "鲁B", "LCode": "3702"},
      {"label": "淄博市", "value": "淄博市", "Pcode": "鲁", "code": "鲁C", "LCode": "3703"},
      {"label": "枣庄市", "value": "枣庄市", "Pcode": "鲁", "code": "鲁D", "LCode": "3704"},
      {"label": "东营市", "value": "东营市", "Pcode": "鲁", "code": "鲁E", "LCode": "3705"},
      {"label": "烟台市", "value": "烟台市", "Pcode": "鲁", "code": "鲁F", "LCode": "3706"},
      {"label": "潍坊市", "value": "潍坊市", "Pcode": "鲁", "code": "鲁G", "LCode": "3707"},
      {"label": "济宁市", "value": "济宁市", "Pcode": "鲁", "code": "鲁H", "LCode": "3708"},
      {"label": "泰安市", "value": "泰安市", "Pcode": "鲁", "code": "鲁J", "LCode": "3709"},
      {"label": "威海市", "value": "威海市", "Pcode": "鲁", "code": "鲁K", "LCode": "3710"},
      {"label": "日照市", "value": "日照市", "Pcode": "鲁", "code": "鲁L", "LCode": "3711"},
      {"label": "莱芜市", "value": "莱芜市", "Pcode": "鲁", "code": "鲁S", "LCode": "3712"},
      {"label": "临沂市", "value": "临沂市", "Pcode": "鲁", "code": "鲁Q", "LCode": "3713"},
      {"label": "德州市", "value": "德州市", "Pcode": "鲁", "code": "鲁N", "LCode": "3714"},
      {"label": "聊城市", "value": "聊城市", "Pcode": "鲁", "code": "鲁P", "LCode": "3715"},
      {"label": "滨州市", "value": "滨州市", "Pcode": "鲁", "code": "鲁M", "LCode": "3716"},
      {"label": "菏泽市", "value": "菏泽市", "Pcode": "鲁", "code": "鲁R", "LCode": "3717"}
    ],
    "label": "山东省",
    "value": "山东省",
    "Pcode": "鲁",
    "LCode": "37"
  },
  {
    "children": [
      {"label": "太原市", "value": "太原市", "Pcode": "晋", "code": "晋A", "LCode": "1401"},
      {"label": "大同市", "value": "大同市", "Pcode": "晋", "code": "晋B", "LCode": "1402"},
      {"label": "阳泉市", "value": "阳泉市", "Pcode": "晋", "code": "晋C", "LCode": "1403"},
      {"label": "长治市", "value": "长治市", "Pcode": "晋", "code": "晋D", "LCode": "1404"},
      {"label": "晋城市", "value": "晋城市", "Pcode": "晋", "code": "晋E", "LCode": "1405"},
      {"label": "朔州市", "value": "朔州市", "Pcode": "晋", "code": "晋F", "LCode": "1406"},
      {"label": "晋中市", "value": "晋中市", "Pcode": "晋", "code": "晋K", "LCode": "1407"},
      {"label": "运城市", "value": "运城市", "Pcode": "晋", "code": "晋M", "LCode": "1408"},
      {"label": "忻州市", "value": "忻州市", "Pcode": "晋", "code": "晋H", "LCode": "1409"},
      {"label": "临汾市", "value": "临汾市", "Pcode": "晋", "code": "晋L", "LCode": "1410"},
      {"label": "吕梁市", "value": "吕梁市", "Pcode": "晋", "code": "晋J", "LCode": "1411"}
    ],
    "label": "山西省",
    "value": "山西省",
    "Pcode": "晋",
    "LCode": "14"
  },
  {
    "children": [
      {"label": "广州市", "value": "广州市", "Pcode": "粤", "code": "粤A", "LCode": "4401"},
      {"label": "韶关市", "value": "韶关市", "Pcode": "粤", "code": "粤F", "LCode": "4402"},
      {"label": "深圳市", "value": "深圳市", "Pcode": "粤", "code": "粤B", "LCode": "4403"},
      {"label": "珠海市", "value": "珠海市", "Pcode": "粤", "code": "粤C", "LCode": "4404"},
      {"label": "汕头市", "value": "汕头市", "Pcode": "粤", "code": "粤D", "LCode": "4405"},
      {"label": "佛山市", "value": "佛山市", "Pcode": "粤", "code": "粤E", "LCode": "4406"},
      {"label": "江门市", "value": "江门市", "Pcode": "粤", "code": "粤J", "LCode": "4407"},
      {"label": "湛江市", "value": "湛江市", "Pcode": "粤", "code": "粤G", "LCode": "4408"},
      {"label": "茂名市", "value": "茂名市", "Pcode": "粤", "code": "粤K", "LCode": "4409"},
      {"label": "肇庆市", "value": "肇庆市", "Pcode": "粤", "code": "粤H", "LCode": "4412"},
      {"label": "惠州市", "value": "惠州市", "Pcode": "粤", "code": "粤L", "LCode": "4413"},
      {"label": "梅州市", "value": "梅州市", "Pcode": "粤", "code": "粤M", "LCode": "4414"},
      {"label": "汕尾市", "value": "汕尾市", "Pcode": "粤", "code": "粤N", "LCode": "4415"},
      {"label": "河源市", "value": "河源市", "Pcode": "粤", "code": "粤P", "LCode": "4416"},
      {"label": "阳江市", "value": "阳江市", "Pcode": "粤", "code": "粤Q", "LCode": "4417"},
      {"label": "清远市", "value": "清远市", "Pcode": "粤", "code": "粤R", "LCode": "4418"},
      {"label": "东莞市", "value": "东莞市", "Pcode": "粤", "code": "粤S", "LCode": "4419"},
      {"label": "中山市", "value": "中山市", "Pcode": "粤", "code": "粤T", "LCode": "4420"},
      {"label": "潮州市", "value": "潮州市", "Pcode": "粤", "code": "粤U", "LCode": "4451"},
      {"label": "揭阳市", "value": "揭阳市", "Pcode": "粤", "code": "粤V", "LCode": "4452"},
      {"label": "云浮市", "value": "云浮市", "Pcode": "粤", "code": "粤W", "LCode": "4453"}
    ],
    "label": "广东省",
    "value": "广东省",
    "Pcode": "粤",
    "LCode": "44"
  },
  {
    "children": [
      {"label": "南宁市", "value": "南宁市", "Pcode": "桂", "code": "桂A", "LCode": "4501"},
      {"label": "柳州市", "value": "柳州市", "Pcode": "桂", "code": "桂B", "LCode": "4502"},
      {"label": "桂林市", "value": "桂林市", "Pcode": "桂", "code": "桂C", "LCode": "4503"},
      {"label": "梧州市", "value": "梧州市", "Pcode": "桂", "code": "桂D", "LCode": "4504"},
      {"label": "北海市", "value": "北海市", "Pcode": "桂", "code": "桂E", "LCode": "4505"},
      {"label": "防城港市", "value": "防城港市", "Pcode": "桂", "code": "桂P", "LCode": "4506"},
      {"label": "钦州市", "value": "钦州市", "Pcode": "桂", "code": "桂N", "LCode": "4507"},
      {"label": "贵港市", "value": "贵港市", "Pcode": "桂", "code": "桂R", "LCode": "4508"},
      {"label": "玉林市", "value": "玉林市", "Pcode": "桂", "code": "桂K", "LCode": "4509"},
      {"label": "百色市", "value": "百色市", "Pcode": "桂", "code": "桂L", "LCode": "4510"},
      {"label": "贺州市", "value": "贺州市", "Pcode": "桂", "code": "桂J", "LCode": "4511"},
      {"label": "河池市", "value": "河池市", "Pcode": "桂", "code": "桂M", "LCode": "4512"},
      {"label": "来宾市", "value": "来宾市", "Pcode": "桂", "code": "桂G", "LCode": "4513"},
      {"label": "崇左市", "value": "崇左市", "Pcode": "桂", "code": "桂F", "LCode": "4514"}
    ],
    "label": "广西壮族自治区",
    "value": "广西壮族自治区",
    "Pcode": "桂",
    "LCode": "45"
  },
  {
    "children": [
      {"label": "乌鲁木齐市", "value": "乌鲁木齐市", "Pcode": "新", "code": "新A", "LCode": "6501"},
      {"label": "克拉玛依市", "value": "克拉玛依市", "Pcode": "新", "code": "新J", "LCode": "6502"},
      {"label": "吐鲁番市", "value": "吐鲁番市", "Pcode": "新", "code": "新K", "LCode": "6521"},
      {"label": "哈密市", "value": "哈密市", "Pcode": "新", "code": "新L", "LCode": "6522"},
      {"label": "昌吉回族自治州", "value": "昌吉回族自治州", "Pcode": "新", "code": "新B", "LCode": "6523"},
      {"label": "博尔塔拉蒙古自治州", "value": "博尔塔拉蒙古自治州", "Pcode": "新", "code": "新E", "LCode": "6527"},
      {"label": "巴音郭楞蒙古自治州", "value": "巴音郭楞蒙古自治州", "Pcode": "新", "code": "新M", "LCode": "6528"},
      {"label": "阿克苏地区", "value": "阿克苏地区", "Pcode": "新", "code": "新N", "LCode": "652900"},
      {"label": "克孜勒苏柯尔克孜自治州", "value": "克孜勒苏柯尔克孜自治州", "Pcode": "新", "code": "新P", "LCode": "6530"},
      {"label": "喀什地区", "value": "喀什地区", "Pcode": "新", "code": "新Q", "LCode": "6531"},
      {"label": "和田地区", "value": "和田地区", "Pcode": "新", "code": "新R", "LCode": "6532"},
      {"label": "伊犁哈萨克自治州", "value": "伊犁哈萨克自治州", "Pcode": "新", "code": "新F", "LCode": "6540"},
      {"label": "塔城地区", "value": "塔城地区", "Pcode": "新", "code": "新G", "LCode": "6542"},
      {"label": "阿勒泰地区", "value": "阿勒泰地区", "Pcode": "新", "code": "新H", "LCode": "654300"},
      {"label": "石河子市", "value": "石河子市", "Pcode": "新", "code": "新C", "LCode": "6590"},
      {"label": "阿拉尔市", "value": "阿拉尔市", "Pcode": "新", "code": "新N", "LCode": "1529"},
      {"label": "图木舒克市", "value": "图木舒克市", "Pcode": "新", "code": "新Q", "LCode": "659003"},
      {"label": "五家渠市", "value": "五家渠市", "Pcode": "新", "code": "新B", "LCode": "659004"},
      {"label": "铁门关市", "value": "铁门关市", "Pcode": "新", "code": "新M", "LCode": "659006"}
    ],
    "label": "新疆维吾尔自治区",
    "value": "新疆维吾尔自治区",
    "Pcode": "新",
    "LCode": "65"
  },
  {
    "children": [
      {"label": "南京市", "value": "南京市", "Pcode": "苏", "code": "苏A", "LCode": "3201"},
      {"label": "无锡市", "value": "无锡市", "Pcode": "苏", "code": "苏B", "LCode": "3202"},
      {"label": "徐州市", "value": "徐州市", "Pcode": "苏", "code": "苏C", "LCode": "3203"},
      {"label": "常州市", "value": "常州市", "Pcode": "苏", "code": "苏D", "LCode": "3204"},
      {"label": "苏州市", "value": "苏州市", "Pcode": "苏", "code": "苏E", "LCode": "3205"},
      {"label": "南通市", "value": "南通市", "Pcode": "苏", "code": "苏F", "LCode": "3206"},
      {"label": "连云港市", "value": "连云港市", "Pcode": "苏", "code": "苏G", "LCode": "3207"},
      {"label": "淮安市", "value": "淮安市", "Pcode": "苏", "code": "苏H", "LCode": "3208"},
      {"label": "盐城市", "value": "盐城市", "Pcode": "苏", "code": "苏J", "LCode": "3209"},
      {"label": "扬州市", "value": "扬州市", "Pcode": "苏", "code": "苏K", "LCode": "3210"},
      {"label": "镇江市", "value": "镇江市", "Pcode": "苏", "code": "苏L", "LCode": "3211"},
      {"label": "泰州市", "value": "泰州市", "Pcode": "苏", "code": "苏M", "LCode": "3212"},
      {"label": "宿迁市", "value": "宿迁市", "Pcode": "苏", "code": "苏N", "LCode": "321300"}
    ],
    "label": "江苏省",
    "value": "江苏省",
    "Pcode": "苏",
    "LCode": "32"
  },
  {
    "children": [
      {"label": "南昌市", "value": "南昌市", "Pcode": "赣", "code": "赣A", "LCode": "3601"},
      {"label": "景德镇市", "value": "景德镇市", "Pcode": "赣", "code": "赣H", "LCode": "3602"},
      {"label": "萍乡市", "value": "萍乡市", "Pcode": "赣", "code": "赣J", "LCode": "3603"},
      {"label": "九江市", "value": "九江市", "Pcode": "赣", "code": "赣G", "LCode": "3604"},
      {"label": "新余市", "value": "新余市", "Pcode": "赣", "code": "赣K", "LCode": "3605"},
      {"label": "鹰潭市", "value": "鹰潭市", "Pcode": "赣", "code": "赣L", "LCode": "3606"},
      {"label": "赣州市", "value": "赣州市", "Pcode": "赣", "code": "赣B", "LCode": "3607"},
      {"label": "吉安市", "value": "吉安市", "Pcode": "赣", "code": "赣D", "LCode": "3608"},
      {"label": "宜春市", "value": "宜春市", "Pcode": "赣", "code": "赣C", "LCode": "3609"},
      {"label": "抚州市", "value": "抚州市", "Pcode": "赣", "code": "赣F", "LCode": "3610"},
      {"label": "上饶市", "value": "上饶市", "Pcode": "赣", "code": "赣E", "LCode": "3611"}
    ],
    "label": "江西省",
    "value": "江西省",
    "Pcode": "赣",
    "LCode": "36"
  },
  {
    "children": [
      {"label": "石家庄市", "value": "石家庄市", "Pcode": "冀", "code": "冀A", "LCode": "1301"},
      {"label": "唐山市", "value": "唐山市", "Pcode": "冀", "code": "冀B", "LCode": "1302"},
      {"label": "秦皇岛市", "value": "秦皇岛市", "Pcode": "冀", "code": "冀C", "LCode": "1303"},
      {"label": "邯郸市", "value": "邯郸市", "Pcode": "冀", "code": "冀D", "LCode": "1304"},
      {"label": "邢台市", "value": "邢台市", "Pcode": "冀", "code": "冀E", "LCode": "1305"},
      {"label": "保定市", "value": "保定市", "Pcode": "冀", "code": "冀F", "LCode": "1306"},
      {"label": "张家口市", "value": "张家口市", "Pcode": "冀", "code": "冀G", "LCode": "1307"},
      {"label": "承德市", "value": "承德市", "Pcode": "冀", "code": "冀H", "LCode": "1308"},
      {"label": "沧州市", "value": "沧州市", "Pcode": "冀", "code": "冀J", "LCode": "1309"},
      {"label": "廊坊市", "value": "廊坊市", "Pcode": "冀", "code": "冀R", "LCode": "1310"},
      {"label": "衡水市", "value": "衡水市", "Pcode": "冀", "code": "冀T", "LCode": "1311"},
      {"label": "定州市", "value": "定州市", "Pcode": "冀", "code": "冀F", "LCode": "130682"},
      {"label": "辛集市", "value": "辛集市", "Pcode": "冀", "code": "冀A", "LCode": "130181"}
    ],
    "label": "河北省",
    "value": "河北省",
    "Pcode": "冀",
    "LCode": "13"
  },
  {
    "children": [
      {"label": "郑州市", "value": "郑州市", "Pcode": "豫", "code": "豫A", "LCode": "4101"},
      {"label": "开封市", "value": "开封市", "Pcode": "豫", "code": "豫B", "LCode": "4102"},
      {"label": "洛阳市", "value": "洛阳市", "Pcode": "豫", "code": "豫C", "LCode": "4103"},
      {"label": "平顶山市", "value": "平顶山市", "Pcode": "豫", "code": "豫D", "LCode": "4104"},
      {"label": "安阳市", "value": "安阳市", "Pcode": "豫", "code": "豫E", "LCode": "4105"},
      {"label": "鹤壁市", "value": "鹤壁市", "Pcode": "豫", "code": "豫F", "LCode": "4106"},
      {"label": "新乡市", "value": "新乡市", "Pcode": "豫", "code": "豫G", "LCode": "4107"},
      {"label": "焦作市", "value": "焦作市", "Pcode": "豫", "code": "豫H", "LCode": "4108"},
      {"label": "濮阳市", "value": "濮阳市", "Pcode": "豫", "code": "豫J", "LCode": "4109"},
      {"label": "许昌市", "value": "许昌市", "Pcode": "豫", "code": "豫K", "LCode": "4110"},
      {"label": "漯河市", "value": "漯河市", "Pcode": "豫", "code": "豫L", "LCode": "4111"},
      {"label": "三门峡市", "value": "三门峡市", "Pcode": "豫", "code": "豫M", "LCode": "4112"},
      {"label": "南阳市", "value": "南阳市", "Pcode": "豫", "code": "豫R", "LCode": "4113"},
      {"label": "商丘市", "value": "商丘市", "Pcode": "豫", "code": "豫N", "LCode": "4114"},
      {"label": "信阳市", "value": "信阳市", "Pcode": "豫", "code": "豫S", "LCode": "4115"},
      {"label": "周口市", "value": "周口市", "Pcode": "豫", "code": "豫P", "LCode": "4116"},
      {"label": "驻马店市", "value": "驻马店市", "Pcode": "豫", "code": "豫Q", "LCode": "4117"},
      {"label": "济源市", "value": "济源市", "Pcode": "豫", "code": "豫U", "LCode": "419001"}
    ],
    "label": "河南省",
    "value": "河南省",
    "Pcode": "豫",
    "LCode": "41"
  },
  {
    "children": [
      {"label": "杭州市", "value": "杭州市", "Pcode": "浙", "code": "浙A", "LCode": "3301"},
      {"label": "宁波市", "value": "宁波市", "Pcode": "浙", "code": "浙B", "LCode": "3302"},
      {"label": "温州市", "value": "温州市", "Pcode": "浙", "code": "浙C", "LCode": "3303"},
      {"label": "嘉兴市", "value": "嘉兴市", "Pcode": "浙", "code": "浙F", "LCode": "3304"},
      {"label": "湖州市", "value": "湖州市", "Pcode": "浙", "code": "浙E", "LCode": "3305"},
      {"label": "绍兴市", "value": "绍兴市", "Pcode": "浙", "code": "浙D", "LCode": "3306"},
      {"label": "金华市", "value": "金华市", "Pcode": "浙", "code": "浙G", "LCode": "3307"},
      {"label": "衢州市", "value": "衢州市", "Pcode": "浙", "code": "浙H", "LCode": "3308"},
      {"label": "舟山市", "value": "舟山市", "Pcode": "浙", "code": "浙L", "LCode": "3309"},
      {"label": "台州市", "value": "台州市", "Pcode": "浙", "code": "浙J", "LCode": "3310"},
      {"label": "丽水市", "value": "丽水市", "Pcode": "浙", "code": "浙K", "LCode": "3311"}
    ],
    "label": "浙江省",
    "value": "浙江省",
    "Pcode": "浙",
    "LCode": "33"
  },
  {
    "children": [
      {"label": "海口市", "value": "海口市", "Pcode": "琼", "code": "琼A", "LCode": "4601"},
      {"label": "三亚市", "value": "三亚市", "Pcode": "琼", "code": "琼B", "LCode": "4602"},
      {"label": "三沙市", "value": "三沙市", "Pcode": "琼", "code": "琼C", "LCode": "4690"},
      {"label": "儋州市", "value": "儋州市", "Pcode": "琼", "code": "琼F", "LCode": "4690"},
      {"label": "五指山市", "value": "五指山市", "Pcode": "琼", "code": "琼D", "LCode": "469001"},
      {"label": "琼海市", "value": "琼海市", "Pcode": "琼", "code": "琼C", "LCode": "469002"},
      {"label": "文昌市", "value": "文昌市", "Pcode": "琼", "code": "琼C", "LCode": "469005"},
      {"label": "万宁市", "value": "万宁市", "Pcode": "琼", "code": "琼C", "LCode": "469006"},
      {"label": "东方市", "value": "东方市", "Pcode": "琼", "code": "D", "LCode": "469007"},
      {"label": "定安县", "value": "定安县", "Pcode": "琼", "code": "琼C", "LCode": "469021"},
      {"label": "屯昌县", "value": "屯昌县", "Pcode": "琼", "code": "琼C", "LCode": "469022"},
      {"label": "澄迈县", "value": "澄迈县", "Pcode": "琼", "code": "琼C", "LCode": "469023"},
      {"label": "临高县", "value": "临高县", "Pcode": "琼", "code": "琼C", "LCode": "469024"},
      {"label": "白沙黎族自治县", "value": "白沙黎族自治县", "Pcode": "琼", "code": "琼D", "LCode": "469025"},
      {"label": "昌江黎族自治县", "value": "昌江黎族自治县", "Pcode": "琼", "code": "琼D", "LCode": "469026"},
      {"label": "乐东黎族自治县", "value": "乐东黎族自治县", "Pcode": "琼", "code": "琼D", "LCode": "469027"},
      {"label": "陵水黎族自治县", "value": "陵水黎族自治县", "Pcode": "琼", "code": "琼D", "LCode": "469028"},
      {"label": "保亭黎族苗族自治县", "value": "保亭黎族苗族自治县", "Pcode": "琼", "code": "琼D", "LCode": "469029"},
      {"label": "琼中黎族苗族自治县", "value": "琼中黎族苗族自治县", "Pcode": "琼", "code": "琼D", "LCode": "469030"}
    ],
    "label": "海南省",
    "value": "海南省",
    "Pcode": "琼",
    "LCode": "46"
  },
  {
    "children": [
      {"label": "长沙市", "value": "长沙市", "Pcode": "湘", "code": "湘A", "LCode": "4301"},
      {"label": "株洲市", "value": "株洲市", "Pcode": "湘", "code": "湘B", "LCode": "4302"},
      {"label": "湘潭市", "value": "湘潭市", "Pcode": "湘", "code": "湘C", "LCode": "4303"},
      {"label": "衡阳市", "value": "衡阳市", "Pcode": "湘", "code": "湘D", "LCode": "4304"},
      {"label": "邵阳市", "value": "邵阳市", "Pcode": "湘", "code": "湘E", "LCode": "4305"},
      {"label": "岳阳市", "value": "岳阳市", "Pcode": "湘", "code": "湘F", "LCode": "4306"},
      {"label": "常德市", "value": "常德市", "Pcode": "湘", "code": "湘J", "LCode": "4307"},
      {"label": "张家界市", "value": "张家界市", "Pcode": "湘", "code": "湘G", "LCode": "1307"},
      {"label": "益阳市", "value": "益阳市", "Pcode": "湘", "code": "湘H", "LCode": "4309"},
      {"label": "郴州市", "value": "郴州市", "Pcode": "湘", "code": "湘L", "LCode": "4310"},
      {"label": "永州市", "value": "永州市", "Pcode": "湘", "code": "湘M", "LCode": "4311"},
      {"label": "怀化市", "value": "怀化市", "Pcode": "湘", "code": "湘N", "LCode": "4312"},
      {"label": "娄底市", "value": "娄底市", "Pcode": "湘", "code": "湘K", "LCode": "4313"},
      {"label": "湘西土家族苗族自治州", "value": "湘西土家族苗族自治州", "Pcode": "湘", "code": "湘U", "LCode": "4331"}
    ],
    "label": "湖南省",
    "value": "湖南省",
    "Pcode": "湘",
    "LCode": "43"
  },
  {
    "children": [
      {"label": "兰州市", "value": "兰州市", "Pcode": "甘", "code": "甘A", "LCode": "6201"},
      {"label": "嘉峪关市", "value": "嘉峪关市", "Pcode": "甘", "code": "甘B", "LCode": "6202"},
      {"label": "金昌市", "value": "金昌市", "Pcode": "甘", "code": "甘C", "LCode": "6203"},
      {"label": "白银市", "value": "白银市", "Pcode": "甘", "code": "甘D", "LCode": "6204"},
      {"label": "天水市", "value": "天水市", "Pcode": "甘", "code": "甘E", "LCode": "6205"},
      {"label": "武威市", "value": "武威市", "Pcode": "甘", "code": "甘H", "LCode": "6206"},
      {"label": "张掖市", "value": "张掖市", "Pcode": "甘", "code": "甘G", "LCode": "6207"},
      {"label": "平凉市", "value": "平凉市", "Pcode": "甘", "code": "甘L", "LCode": "6208"},
      {"label": "酒泉市", "value": "酒泉市", "Pcode": "甘", "code": "甘F", "LCode": "6209"},
      {"label": "庆阳市", "value": "庆阳市", "Pcode": "甘", "code": "甘M", "LCode": "6210"},
      {"label": "定西市", "value": "定西市", "Pcode": "甘", "code": "甘J", "LCode": "6211"},
      {"label": "陇南市", "value": "陇南市", "Pcode": "甘", "code": "甘K", "LCode": "6212"},
      {"label": "临夏回族自治州", "value": "临夏回族自治州", "Pcode": "甘", "code": "甘N", "LCode": "6229"},
      {"label": "甘南藏族自治州", "value": "甘南藏族自治州", "Pcode": "甘", "code": "甘P", "LCode": "6230"}
    ],
    "label": "甘肃省",
    "value": "甘肃省",
    "Pcode": "甘",
    "LCode": "62"
  },
  {
    "children": [
      {"label": "福州市", "value": "福州市", "Pcode": "闽", "code": "闽A", "LCode": "3501"},
      {"label": "厦门市", "value": "厦门市", "Pcode": "闽", "code": "闽D", "LCode": "3502"},
      {"label": "莆田市", "value": "莆田市", "Pcode": "闽", "code": "闽B", "LCode": "3503"},
      {"label": "三明市", "value": "三明市", "Pcode": "闽", "code": "闽G", "LCode": "3504"},
      {"label": "泉州市", "value": "泉州市", "Pcode": "闽", "code": "闽C", "LCode": "3505"},
      {"label": "漳州市", "value": "漳州市", "Pcode": "闽", "code": "闽E", "LCode": "3506"},
      {"label": "南平市", "value": "南平市", "Pcode": "闽", "code": "闽H", "LCode": "3507"},
      {"label": "龙岩市", "value": "龙岩市", "Pcode": "闽", "code": "闽F", "LCode": "3508"},
      {"label": "宁德市", "value": "宁德市", "Pcode": "闽", "code": "闽J", "LCode": "3509"}
    ],
    "label": "福建省",
    "value": "福建省",
    "Pcode": "闽",
    "LCode": "35"
  },
  {
    "children": [
      {"label": "拉萨市", "value": "拉萨市", "Pcode": "藏", "code": "藏A", "LCode": "5401"},
      {"label": "日喀则市", "value": "日喀则市", "Pcode": "藏", "code": "藏D", "LCode": "5423"},
      {"label": "昌都市", "value": "昌都市", "Pcode": "藏", "code": "藏B", "LCode": "5421"},
      {"label": "林芝市", "value": "林芝市", "Pcode": "藏", "code": "藏G", "LCode": "5426"},
      {"label": "山南市", "value": "山南市", "Pcode": "藏", "code": "藏C", "LCode": "5422"},
      {"label": "那曲地区", "value": "那曲地区", "Pcode": "藏", "code": "藏E"},
      {"label": "阿里地区", "value": "阿里地区", "Pcode": "藏", "code": "藏F", "LCode": "542500"}
    ],
    "label": "西藏自治区",
    "value": "西藏自治区",
    "Pcode": "藏",
    "LCode": "54"
  },
  {
    "children": [
      {"label": "贵阳市", "value": "贵阳市", "Pcode": "贵", "code": "贵A", "LCode": "5201"},
      {"label": "六盘水市", "value": "六盘水市", "Pcode": "贵", "code": "贵B", "LCode": "5202"},
      {"label": "遵义市", "value": "遵义市", "Pcode": "贵", "code": "贵C", "LCode": "5203"},
      {"label": "安顺市", "value": "安顺市", "Pcode": "贵", "code": "贵G", "LCode": "5204"},
      {"label": "毕节市", "value": "毕节市", "Pcode": "贵", "code": "贵F", "LCode": "5205"},
      {"label": "铜仁市", "value": "铜仁市", "Pcode": "贵", "code": "贵D", "LCode": "5206"},
      {"label": "黔西南布依族苗族自治州", "value": "黔西南布依族苗族自治州", "Pcode": "贵", "code": "贵E", "LCode": "5223"},
      {"label": "黔东南苗族侗族自治州", "value": "黔东南苗族侗族自治州", "Pcode": "贵", "code": "贵H", "LCode": "5226"},
      {"label": "黔南布依族苗族自治州", "value": "黔南布依族苗族自治州", "Pcode": "贵", "code": "贵J", "LCode": "5227"}
    ],
    "label": "贵州省",
    "value": "贵州省",
    "Pcode": "贵",
    "LCode": "52"
  },
  {
    "children": [
      {"label": "沈阳市", "value": "沈阳市", "Pcode": "辽", "code": "辽A", "LCode": "2101"},
      {"label": "大连市", "value": "大连市", "Pcode": "辽", "code": "辽B", "LCode": "2102"},
      {"label": "鞍山市", "value": "鞍山市", "Pcode": "辽", "code": "辽C", "LCode": "2103"},
      {"label": "抚顺市", "value": "抚顺市", "Pcode": "辽", "code": "辽D", "LCode": "2104"},
      {"label": "本溪市", "value": "本溪市", "Pcode": "辽", "code": "辽E", "LCode": "2105"},
      {"label": "丹东市", "value": "丹东市", "Pcode": "辽", "code": "辽F", "LCode": "2106"},
      {"label": "锦州市", "value": "锦州市", "Pcode": "辽", "code": "辽G", "LCode": "2107"},
      {"label": "营口市", "value": "营口市", "Pcode": "辽", "code": "辽H", "LCode": "2108"},
      {"label": "阜新市", "value": "阜新市", "Pcode": "辽", "code": "辽J", "LCode": "2109"},
      {"label": "辽阳市", "value": "辽阳市", "Pcode": "辽", "code": "辽K", "LCode": "2110"},
      {"label": "盘锦市", "value": "盘锦市", "Pcode": "辽", "code": "辽L", "LCode": "2111"},
      {"label": "铁岭市", "value": "铁岭市", "Pcode": "辽", "code": "辽M", "LCode": "2112"},
      {"label": "朝阳市", "value": "朝阳市", "Pcode": "辽", "code": "辽N", "LCode": "2113"},
      {"label": "葫芦岛市", "value": "葫芦岛市", "Pcode": "辽", "code": "辽P", "LCode": "2114"}
    ],
    "label": "辽宁省",
    "value": "辽宁省",
    "Pcode": "辽",
    "LCode": "21"
  },
  {
    "children": [
      {"label": "万州区", "value": "万州区", "Pcode": "渝", "code": "渝F", "LCode": "500101"},
      {"label": "涪陵区", "value": "涪陵区", "Pcode": "渝", "code": "渝G", "LCode": "500102"},
      {"label": "渝中区", "value": "渝中区", "Pcode": "渝", "code": "渝A", "LCode": "500103"},
      {"label": "大渡口区", "value": "大渡口区", "Pcode": "渝", "code": "渝B", "LCode": "500104"},
      {"label": "江北区", "value": "江北区", "Pcode": "渝", "code": "渝D", "LCode": "330205"},
      {"label": "沙坪坝区", "value": "沙坪坝区", "Pcode": "渝", "code": "渝F", "LCode": "500106"},
      {"label": "九龙坡区", "value": "九龙坡区", "Pcode": "渝", "code": "渝G", "LCode": "500107"},
      {"label": "南岸区", "value": "南岸区", "Pcode": "渝", "code": "渝H", "LCode": "500108"},
      {"label": "北碚区", "value": "北碚区", "Pcode": "渝", "code": "渝A", "LCode": "500109"},
      {"label": "綦江区", "value": "綦江区", "Pcode": "渝", "code": "渝A", "LCode": "500110"},
      {"label": "大足区", "value": "大足区", "Pcode": "渝", "code": "渝A", "LCode": "500111"},
      {"label": "渝北区", "value": "渝北区", "Pcode": "渝", "code": "渝A", "LCode": "500112"},
      {"label": "巴南区", "value": "巴南区", "Pcode": "渝", "code": "渝A", "LCode": "500113"},
      {"label": "黔江区", "value": "黔江区", "Pcode": "渝", "code": "渝H", "LCode": "500114"},
      {"label": "长寿区", "value": "长寿区", "Pcode": "渝", "code": "渝A", "LCode": "500115"},
      {"label": "江津区", "value": "江津区", "Pcode": "渝", "code": "渝A", "LCode": "500116"},
      {"label": "合川区", "value": "合川区", "Pcode": "渝", "code": "渝A", "LCode": "500117"},
      {"label": "永川区", "value": "永川区", "Pcode": "渝", "code": "渝C", "LCode": "500118"},
      {"label": "南川区", "value": "南川区", "Pcode": "渝", "code": "渝A", "LCode": "500119"},
      {"label": "璧山区", "value": "璧山区", "Pcode": "渝", "code": "渝A", "LCode": "500120"},
      {"label": "铜梁区", "value": "铜梁区", "Pcode": "渝", "code": "渝A", "LCode": "500151"},
      {"label": "潼南区", "value": "潼南区", "Pcode": "渝", "code": "渝A", "LCode": "500152"},
      {"label": "荣昌区", "value": "荣昌区", "Pcode": "渝", "code": "渝A", "LCode": "500153"},
      {"label": "开州区", "value": "开州区", "Pcode": "渝", "code": "渝A", "LCode": "500154"},
      {"label": "梁平县", "value": "梁平县", "Pcode": "渝", "code": "渝A"},
      {"label": "城口县", "value": "城口县", "Pcode": "渝", "code": "渝A", "LCode": "500229"},
      {"label": "丰都县", "value": "丰都县", "Pcode": "渝", "code": "渝A", "LCode": "500230"},
      {"label": "垫江县", "value": "垫江县", "Pcode": "渝", "code": "渝A", "LCode": "500231"},
      {"label": "武隆县", "value": "武隆县", "Pcode": "渝", "code": "渝A"},
      {"label": "忠县", "value": "忠县", "Pcode": "渝", "code": "渝A", "LCode": "500233"},
      {"label": "云阳县", "value": "云阳县", "Pcode": "渝", "code": "渝A", "LCode": "500235"},
      {"label": "奉节县", "value": "奉节县", "Pcode": "渝", "code": "渝A", "LCode": "500236"},
      {"label": "巫山县", "value": "巫山县", "Pcode": "渝", "code": "渝A", "LCode": "500237"},
      {"label": "巫溪县", "value": "巫溪县", "Pcode": "渝", "code": "渝A", "LCode": "500238"},
      {"label": "石柱土家族自治县", "value": "石柱土家族自治县", "Pcode": "渝", "code": "渝A", "LCode": "500240"},
      {"label": "秀山土家族苗族自治县", "value": "秀山土家族苗族自治县", "Pcode": "渝", "code": "渝A", "LCode": "500241"},
      {"label": "酉阳土家族苗族自治县", "value": "酉阳土家族苗族自治县", "Pcode": "渝", "code": "渝A", "LCode": "500242"},
      {"label": "彭水苗族土家族自治县", "value": "彭水苗族土家族自治县", "Pcode": "渝", "code": "渝A", "LCode": "500243"}
    ],
    "label": "重庆市",
    "value": "重庆市",
    "Pcode": "渝",
    "LCode": "50"
  },
  {
    "children": [
      {"label": "西安市", "value": "西安市", "Pcode": "陕", "code": "陕A", "LCode": "6101"},
      {"label": "铜川市", "value": "铜川市", "Pcode": "陕", "code": "陕B", "LCode": "6102"},
      {"label": "宝鸡市", "value": "宝鸡市", "Pcode": "陕", "code": "陕C", "LCode": "6103"},
      {"label": "咸阳市", "value": "咸阳市", "Pcode": "陕", "code": "陕D", "LCode": "6104"},
      {"label": "渭南市", "value": "渭南市", "Pcode": "陕", "code": "陕E", "LCode": "6105"},
      {"label": "延安市", "value": "延安市", "Pcode": "陕", "code": "陕J", "LCode": "6106"},
      {"label": "汉中市", "value": "汉中市", "Pcode": "陕", "code": "陕F", "LCode": "6107"},
      {"label": "榆林市", "value": "榆林市", "Pcode": "陕", "code": "陕K", "LCode": "6108"},
      {"label": "安康市", "value": "安康市", "Pcode": "陕", "code": "陕G", "LCode": "6109"},
      {"label": "商洛市", "value": "商洛市", "Pcode": "陕", "code": "陕H", "LCode": "6110"}
    ],
    "label": "陕西省",
    "value": "陕西省",
    "Pcode": "陕",
    "LCode": "61"
  },
  {
    "children": [
      {"label": "西宁市", "value": "西宁市", "Pcode": "青", "code": "青A", "LCode": "6301"},
      {"label": "海东市", "value": "海东市", "Pcode": "青", "code": "青B", "LCode": "6321"},
      {"label": "海北藏族自治州", "value": "海北藏族自治州", "Pcode": "青", "code": "青C", "LCode": "6322"},
      {"label": "黄南藏族自治州", "value": "黄南藏族自治州", "Pcode": "青", "code": "青D", "LCode": "6323"},
      {"label": "海南藏族自治州", "value": "海南藏族自治州", "Pcode": "青", "code": "青E", "LCode": "6325"},
      {"label": "果洛藏族自治州", "value": "果洛藏族自治州", "Pcode": "青", "code": "青F", "LCode": "6326"},
      {"label": "玉树藏族自治州", "value": "玉树藏族自治州", "Pcode": "青", "code": "青G", "LCode": "6327"},
      {"label": "海西蒙古族藏族自治州", "value": "海西蒙古族藏族自治州", "Pcode": "青", "code": "青H", "LCode": "6328"}
    ],
    "label": "青海省",
    "value": "青海省",
    "Pcode": "青",
    "LCode": "63"
  },
  {
    "children": [
      {"label": "哈尔滨市", "value": "哈尔滨市", "Pcode": "黑", "code": "黑A", "LCode": "2301"},
      {"label": "齐齐哈尔市", "value": "齐齐哈尔市", "Pcode": "黑", "code": "黑B", "LCode": "2302"},
      {"label": "鸡西市", "value": "鸡西市", "Pcode": "黑", "code": "黑G", "LCode": "2303"},
      {"label": "鹤岗市", "value": "鹤岗市", "Pcode": "黑", "code": "黑H", "LCode": "2304"},
      {"label": "双鸭山市", "value": "双鸭山市", "Pcode": "黑", "code": "黑J", "LCode": "2305"},
      {"label": "大庆市", "value": "大庆市", "Pcode": "黑", "code": "黑E", "LCode": "2306"},
      {"label": "伊春市", "value": "伊春市", "Pcode": "黑", "code": "黑F", "LCode": "2307"},
      {"label": "佳木斯市", "value": "佳木斯市", "Pcode": "黑", "code": "黑D", "LCode": "2308"},
      {"label": "七台河市", "value": "七台河市", "Pcode": "黑", "code": "黑K", "LCode": "2309"},
      {"label": "牡丹江市", "value": "牡丹江市", "Pcode": "黑", "code": "黑C", "LCode": "2310"},
      {"label": "黑河市", "value": "黑河市", "Pcode": "黑", "code": "黑N", "LCode": "2311"},
      {"label": "绥化市", "value": "绥化市", "Pcode": "黑", "code": "黑M", "LCode": "2312"},
      {"label": "大兴安岭地区", "value": "大兴安岭地区", "Pcode": "黑", "code": "黑P", "LCode": "2327"}
    ],
    "label": "黑龙江省",
    "value": "黑龙江省",
    "Pcode": "黑",
    "LCode": "23"
  },
  {
    "label": "香港",
    "value": "香港",
    "Pcode": "港",
    "LCode": "81",
    "children": [
      {
        "label": "香港",
        "value": "香港",
        "Pcode": "港",
        "code": "港",
        "LCode": "8100",
      }
    ]
  },
  {
    "label": "澳门",
    "value": "澳门",
    "LCode": "82",
    "children": [
      {
        "label": "澳门",
        "value": "澳门",
        "Pcode": "澳",
        "code": "澳",
        "LCode": "8200",
      }
    ],
    "Pcode": "澳"
  },
  {
    "label": "台湾省",
    "value": "台湾省",
    "Pcode": "台",
    "LCode": "71",
    "children": [
      {
        "label": "台北市",
        "value": "台北市",
        "Pcode": "台",
        "code": "台",
        "LCode": "7100",
      },
      {
        "label": "新北市",
        "value": "新北市",
        "Pcode": "台",
        "code": "台",
        "LCode": "7100",
      },
      {
        "label": "桃园市",
        "value": "桃园市",
        "Pcode": "台",
        "code": "台",
        "LCode": "7100",
      },
      {
        "label": "台中市",
        "value": "台中市",
        "Pcode": "台",
        "code": "台",
        "LCode": "7100",
      },
      {
        "label": "台南市",
        "value": "台南市",
        "Pcode": "台",
        "code": "台",
        "LCode": "7100",
      },
      {
        "label": "高雄市",
        "value": "高雄市",
        "Pcode": "台",
        "code": "台",
        "LCode": "7100",
      }
    ]
  }
];
