import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class TCheckBox extends StatelessWidget {
  const TCheckBox({
    Key? key,
    required this.title,
    required this.isSelected,
    this.onChange,
    this.isDisabled=false
  }) : super(key: key);

  final String title;
  final bool isSelected;
  final Function(bool)? onChange;
  final bool isDisabled;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () {
        if(!isDisabled) {
          onChange?.call(!isSelected);
        }
      },
      child: Ink(
        child: Container(
          padding: EdgeInsets.symmetric(vertical: 15.h),
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              SizedBox(
                width: 24.r,
                height: 24.r,
                child: Checkbox(
                    shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(4.r)),
                    fillColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
                      const Set<MaterialState> interactiveStates = <MaterialState>{
                        MaterialState.pressed,
                        MaterialState.hovered,
                        MaterialState.focused,
                        MaterialState.disabled
                      };
                      if (states.contains(MaterialState.disabled)) {
                        return ThemeData.from(colorScheme: const ColorScheme.light()).disabledColor;
                      }
                      if (states.contains(MaterialState.selected)) {
                        return const Color(0xff2B6BD8);
                      }
                      if (states.any(interactiveStates.contains)) {
                        return Colors.red;
                      }
                      // 最终返回
                      return const Color(0xffC8C9CC);
                    }),
                    value: isSelected,
                    onChanged: isDisabled ? null : (value) {
                      onChange?.call(value!);
                    }),
              ),
              SizedBox(
                width: 8.r,
              ),
              Expanded(
                child: Text(
                  title,
                  style: isSelected ? TextStyle(color: const Color(0xff323233), fontSize: 16.sp, height: 1.5) : TextStyle(color: const Color(0xff969799), fontSize: 16.sp, height: 1.5),
                ),
              )
            ],
          ),
        ),
      ),
    );
  }
}