import 'package:bruno/bruno.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

void showAlertDialog(BuildContext context, String title, void Function()? onConfirm, {String? message, bool showIcon = false}) {
  return BrnDialogManager.showConfirmDialog(context,
      title: title,
      cancel: "",
      confirm: "",
      message: message,
      showIcon: showIcon,
      conformWidget: TextButton(
          onPressed: () {
            Navigator.of(context).pop();
            onConfirm!();
          },
          child: const Text(
            "确定",
            style: TextStyle(fontSize: 16, color: Color(0xff1989FA)),
          )),
      cancelWidget: TextButton(
          onPressed: () {
            Navigator.of(context).pop();
          },
          child: const Text(
            "取消",
            style: TextStyle(fontSize: 16, color: Color(0xff323233)),
          )),
      themeData: BrnDialogConfig(
        titleTextStyle: BrnTextStyle(color: const Color(0xff323233), fontSize: 17),
      ));
}

dynamic showAlertDialogCustom({
  String? title,
  String? message,
  String cancel = "取消",
  GestureTapCallback? onCancel,
  String confirm = "确定",
  GestureTapCallback? onConfirm,
  BuildContext? context,
}) {
  return showConfirmDialog(
    context!,
    cancel: cancel,
    confirm: confirm,
    title: title,
    message: message,
    cancelWidget: TextButton(
        onPressed: () {
          Navigator.of(context).pop();
          if (onCancel != null) {
            onCancel();
          }
        },
        child: Text(
          cancel,
          style: TextStyle(fontSize: 16.sp, color: const Color(0xff323233)),
        )),
    conformWidget: TextButton(
        onPressed: () {
          Navigator.of(context).pop();
          if (onConfirm != null) {
            onConfirm();
          }
        },
        child: Text(
          confirm,
          style: TextStyle(fontSize: 16.sp, color: const Color(0xff1989FA)),
        )),
  );
}

dynamic showAlertDialogCustom3({
  String? title,
  String? message,
  String cancel = "取消",
  GestureTapCallback? onCancel,
  String confirm = "确定",
  GestureTapCallback? onConfirm,
  BuildContext? context,
}) {
  return showConfirmDialog(
    context!,
    cancel: cancel,
    confirm: confirm,
    title: title,
    message: message,
    cancelWidget: TextButton(
        onPressed: () {
          Navigator.of(context).pop();
          if (onCancel != null) {
            onCancel();
          }
        },
        child: Text(
          cancel,
          style: TextStyle(fontSize: 16.sp, color: const Color(0xff1989FA)),
        )),
    conformWidget: TextButton(
        onPressed: () {
          Navigator.of(context).pop();
          if (onConfirm != null) {
            onConfirm();
          }
        },
        child: Text(
          confirm,
          style: TextStyle(fontSize: 16.sp, color: const Color(0xff323233)),
        )),
  );
}

dynamic showAlertDialogCustom1({String? title, String? message, Widget? messageWidget, String cancel = "", String confirm = "确定", GestureTapCallback? onConfirm, BuildContext? context}) {
  return showConfirmDialog(
    context!,
    cancel: cancel,
    confirm: confirm,
    title: title,
    message: message,
    messageWidget: messageWidget,
    cancelWidget: null,
    conformWidget: TextButton(
        onPressed: () {
          Navigator.of(context).pop();
          if (onConfirm != null) {
            onConfirm();
          }
        },
        child: Text(
          confirm,
          style: TextStyle(fontSize: 16.sp, color: const Color(0xff1989FA)),
        )),
  );
}

showConfirmDialog(
  BuildContext context, {
  required String cancel,
  required String confirm,
  bool showIcon = false,
  Image? iconWidget,
  String? title,
  Widget? titleWidget,
  String? message,
  Widget? messageWidget,
  String? warning,
  Widget? warningWidget,
  Widget? cancelWidget,
  Widget? conformWidget,
  GestureTapCallback? onCancel,
  GestureTapCallback? onConfirm,
  bool barrierDismissible = false,
  int titleMaxLines = cTitleMaxLines,
  BrnDialogConfig? themeData,
}) {
  List<Widget> actionsWidget = [];

  if (cancelWidget != null) {
    actionsWidget.add(cancelWidget);
  }
  if (conformWidget != null) {
    actionsWidget.add(conformWidget);
  }
  showDialog<void>(
      context: context,
      barrierDismissible: barrierDismissible,
      builder: (BuildContext dialogContext) {
        return WillPopScope(
            child: BrnDialog(
              iconImage: iconWidget,
              showIcon: showIcon,
              titleText: title,
              titleWidget: titleWidget,
              messageText: message,
              contentWidget: messageWidget,
              warningWidget: warningWidget,
              warningText: warning,
              themeData: themeData,
              titleMaxLines: titleMaxLines,
              actionsText: [cancel, confirm],
              actionsWidget: actionsWidget,
              indexedActionCallback: (index) {
                if (index == 0) {
                  if (onCancel != null) {
                    onCancel();
                  }
                }
                if (index == 1) {
                  if (onConfirm != null) {
                    onConfirm();
                  }
                }
              },
            ),
            onWillPop: () async {
              return false;
            });
      });
}
