import 'package:flutter/material.dart';

class GridTapWidget extends StatefulWidget {

  const GridTapWidget({Key? key, required this.child, required this.onTap}) : super(key: key);

  final Widget child;
  final void Function() onTap;

  @override
  State<StatefulWidget> createState() {return _GridTapWidgetState();}
}

class _GridTapWidgetState extends State<GridTapWidget> with SingleTickerProviderStateMixin {

  late Animation<double> animation;
  late AnimationController controller;

  @override
  void initState() {
    controller = AnimationController(duration: const Duration(milliseconds: 200), vsync: this);
    animation = Tween(begin: 0.0, end: 1.0).animate(controller);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: AnimatedBuilder(animation: animation,
      builder: (BuildContext context, child) {
        return Container(
          foregroundDecoration: BoxDecoration(
              color: Colors.white.withOpacity(0.5 * controller.value),
          ),
          child: widget.child,
        );
      },),
      onTap: widget.onTap,
      onTapDown: (d)=>controller.forward(),
      onTapUp: (d)=>prepareToIdle(),
      onTapCancel: ()=>prepareToIdle(),
    );
  }

  void prepareToIdle() {
    controller.reverse();
  }

  @override
  void dispose() {
    controller.stop();
    controller.dispose();
    super.dispose();
  }
  
}