// ignore_for_file: file_names

import 'package:flutter/widgets.dart';
import 'package:keyboard_dismisser/keyboard_dismisser.dart';

abstract class KeyboardDismissStatelessWidget extends StatelessWidget {
  const KeyboardDismissStatelessWidget({Key? key}) : super(key: key);

  Widget buildContent(BuildContext context);

  @override
  Widget build(BuildContext context) {
    return KeyboardDismisser(
      behavior: HitTestBehavior.translucent,
      gestures: const [
        GestureType.onTap,
        GestureType.onPanUpdateUpDirection,
        GestureType.onPanUpdateDownDirection,
      ],
      child: NotificationListener<ScrollUpdateNotification>(
        onNotification: (ScrollUpdateNotification notification) {
          if (notification.dragDetails != null) {
            hideKeyboard(context);
          }
          return true;
        },
        child: buildContent(context),
      ),
    );
  }
}

abstract class KeyboardDismissState<T extends StatefulWidget> extends State<T> {
  Widget buildContent(BuildContext context);

  @override
  Widget build(BuildContext context) {
    return KeyboardDismisser(
      behavior: HitTestBehavior.translucent,
      gestures: const [
        GestureType.onTap,
        GestureType.onPanUpdateUpDirection,
        GestureType.onPanUpdateDownDirection,
      ],
      child: NotificationListener<ScrollUpdateNotification>(
        onNotification: (ScrollUpdateNotification notification) {
          if (notification.dragDetails != null) {
            hideKeyboard(context);
          }
          return true;
        },
        child: buildContent(context),
      ),
    );
  }
}

void hideKeyboard(BuildContext context) {
  try{
    FocusScopeNode currentFocus = FocusScope.of(context);
    if (!currentFocus.hasPrimaryFocus && currentFocus.focusedChild != null) {
      FocusManager.instance.primaryFocus!.unfocus();
    }
  }catch(_){}
}
