import 'package:common_utils/common_utils.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import 'textField.dart';

class ListItem<T> extends StatelessWidget {
  ListItem(
      {Key? key,
      required this.title,
      this.titleRightIcon,
      this.titleCrossAlignment = CrossAxisAlignment.start,
      this.hintText,
      this.rightTitle,
      this.withTrail = false,
      this.withLine = true,
      this.onTap,
      this.subTitle,
      this.isRequire = false,
      this.titleFlex = 1,
      this.titleMaxLines,
      this.rightFlex = 2,
      this.isError = false,
      this.rightIcon = const Icon(
        Icons.keyboard_arrow_down,
        color: Color(0xffc8c9cc),
        size: 16.0,
      ),
      this.titleStyle = const TextStyle(color: Color(0xff323233), fontSize: 14, height: 1.5),
      this.rightValueStyle = const TextStyle(color: Color(0xff323233), fontSize: 15, height: 1.5),
      this.padding = const EdgeInsets.symmetric(vertical: 10)})
      : super(key: key);

  final String title;
  final Widget? titleRightIcon;
  final CrossAxisAlignment titleCrossAlignment;
  final String? hintText;
  final T? rightTitle;
  final T? subTitle;
  final bool withTrail;
  final bool withLine;
  final bool isRequire;
  final Function()? onTap;
  final Widget? rightIcon;
  final int titleFlex;
  final int? titleMaxLines;
  final int rightFlex;
  final bool isError;
  final TextStyle titleStyle;
  final TextStyle rightValueStyle;
  final EdgeInsets padding;

  final TextStyle requireStyle = TextStyle(color: Colors.red, fontSize: 16.sp);
  final TextStyle hintStyle = TextStyle(color: const Color(0xff969799), fontSize: 16.sp, height: 1.5);

  _renderTitle() {
    return Expanded(
      child: Container(
        margin: EdgeInsets.only(right: 12.w),
        alignment: Alignment.centerLeft,
        child: Row(crossAxisAlignment: CrossAxisAlignment.start, children: [
          Text(
            '*',
            style: isRequire ? requireStyle : const TextStyle(color: Colors.transparent),
          ),
          titleRightIcon == null
              ? Expanded(
                  child: Text(
                    title,
                    style: titleStyle,
                    maxLines: titleMaxLines ?? 2,
                    overflow: TextOverflow.ellipsis,
                    textAlign: TextAlign.left,
                  ),
                )
              : Expanded(
                  child: Row(children: [
                    Text(
                      title,
                      style: titleStyle,
                      maxLines: 2,
                      overflow: TextOverflow.ellipsis,
                      textAlign: TextAlign.left,
                    ),
                    titleRightIcon ?? const SizedBox.shrink()
                  ]),
                )
        ]),
      ),
      flex: titleFlex,
    );
  }

  _renderRightTitle(String rt) {
    return Expanded(
      child: Row(
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Expanded(
            child: Container(
              alignment: Alignment.topLeft,
              child: Text(
                rt,
                textAlign: TextAlign.left,
                style: rightValueStyle,
                softWrap: true,
                textDirection: TextDirection.ltr,
              ),
            ),
          ),
          SizedBox(
            width: 5.r,
          ),
          Offstage(
            offstage: !withTrail,
            child: rightIcon,
          ),
        ],
      ),
      flex: rightFlex,
    );
  }

  _renderHintText() {
    return Expanded(
      child: Row(
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Expanded(
            child: Container(
              alignment: Alignment.centerLeft,
              child: Text(
                hintText ?? "",
                textAlign: TextAlign.left,
                style: hintStyle,
                softWrap: true,
                textDirection: TextDirection.ltr,
              ),
            ),
          ),
          Offstage(
            offstage: !withTrail,
            child: rightIcon,
          ),
        ],
      ),
      flex: rightFlex,
    );
  }

  _renderRightWidget() {
    return Expanded(
      child: Row(
        children: [
          Expanded(
              child: Container(
            constraints: BoxConstraints(minHeight: 24.h),
            alignment: Alignment.centerLeft,
            child: rightTitle as Widget,
          )),
          Offstage(
            offstage: !withTrail,
            child: rightIcon,
          ),
        ],
      ),
      flex: rightFlex,
    );
  }

  _renderRight() {
    if (rightTitle != null) {
      if (rightTitle is String || rightTitle is num) {
        String rt = (rightTitle is String) ? rightTitle as String : rightTitle.toString();
        if (rt.isNotEmpty) {
          return _renderRightTitle(rt);
        } else {
          return _renderHintText();
        }
      }
      return _renderRightWidget();
    } else {
      return _renderHintText();
    }
  }

  _renderSubTitle() {
    if (subTitle != null) {
      return Container(
        margin: EdgeInsets.only(bottom: 10.h),
        child: subTitle as Widget,
      );
    }
    return const SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      child: Ink(
        child: Container(
          padding: padding,
          decoration: BoxDecoration(
            border: Border(bottom: withLine ? const BorderSide(color: Color(0xffF7F8FA)) : BorderSide.none),
          ),
          child: Container(
            padding: const EdgeInsets.symmetric(vertical: 6),
            decoration: isError ? BoxDecoration(borderRadius: BorderRadius.all(Radius.circular(4.r)), color: const Color(0xffFBE5E5).withOpacity(0.6)) : const BoxDecoration(),
            child: Column(
              children: [
                Row(
                  mainAxisSize: MainAxisSize.max,
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: titleCrossAlignment,
                  children: [
                    _renderTitle(),
                    _renderRight(),
                  ],
                ),
                _renderSubTitle(),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class ListItemTextInput extends StatefulWidget {
  const ListItemTextInput({Key? key, this.hintText = "请输入", this.minLines = 1, this.maxLines, this.onChange, this.textInputType, this.defaultValue, this.maxLength = 5000, this.enable = true,}) : super(key: key);
  final String hintText;
  final int minLines;
  final int? maxLines;
  final Function(String)? onChange;
  final String? defaultValue;
  final TextInputType? textInputType;
  final int? maxLength;
  final bool enable;

  @override
  State<ListItemTextInput> createState() => _ListItemTextInputState();
}

class _ListItemTextInputState extends State<ListItemTextInput> {
  late TextEditingController _inputController = TextEditingController(text: widget.defaultValue)..addListener(_handleValueChange);

  @override
  void didUpdateWidget(ListItemTextInput oldWidget) {
    if (oldWidget.defaultValue != widget.defaultValue) {
      String text = widget.defaultValue ?? "";
      _inputController = TextEditingController(text: text)
        ..selection = TextSelection.fromPosition(TextPosition(offset: text.length))
        ..addListener(_handleValueChange);
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return TextField(
      enabled: widget.enable,
      controller: _inputController,
      maxLines: widget.maxLines,
      minLines: widget.minLines,
      keyboardType: widget.textInputType,
      decoration: InputDecoration(
        isDense: true,
        contentPadding: EdgeInsets.zero,
        border: InputBorder.none,
        hintMaxLines: 2,
        hintText: widget.hintText,
        hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 14.sp),
      ),
      style: TextStyle(color: const Color(0xff323233), fontSize: 16.sp),
      inputFormatters: [
        LengthLimitingTextInputFormatter(widget.maxLength),
      ],
    );
  }

  @override
  void dispose() {
    super.dispose();
    _inputController.removeListener(_handleValueChange);
    _inputController.dispose();
  }

  void _handleValueChange() {
    widget.onChange?.call(_inputController.text);
  }
}

class ListItemTimerRange extends StatelessWidget {
  ListItemTimerRange({Key? key, this.startTime, this.endTime}) : super(key: key);
  final String? startTime;
  final String? endTime;

  final TextStyle valueStyle = TextStyle(
    color: const Color(0xff323233),
    fontSize: 16.sp,
  );
  final TextStyle hintStyle = TextStyle(
    color: const Color(0xff969799),
    fontSize: 14.sp,
  );

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisSize: MainAxisSize.min,
      children: [
        startTime != null && startTime!.isNotEmpty
            ? Expanded(
                child: Text(
                  DateUtil.formatDate(DateTime.tryParse(startTime!), format: DateFormats.y_mo_d),
                  style: valueStyle,
                  maxLines: 1,
                  overflow: TextOverflow.ellipsis,
                ),
              )
            : Text(
                "开始时间",
                style: hintStyle,
              ),
        Text(
          '~',
          style: valueStyle,
        ),
        endTime != null && endTime!.isNotEmpty
            ? Expanded(
                child: Text(
                  DateUtil.formatDate(DateTime.tryParse(endTime!), format: DateFormats.y_mo_d),
                  style: valueStyle,
                  maxLines: 1,
                  overflow: TextOverflow.ellipsis,
                ),
              )
            : Text(
                "结束时间",
                style: hintStyle,
              ),
      ],
    );
  }
}

class ListItemMileInput extends StatefulWidget {
  const ListItemMileInput({Key? key, this.startMile, this.endMile, this.enable = true, this.onFocusChange, this.onChange}) : super(key: key);
  final int? startMile;
  final int? endMile;
  final Function(int? start, int? end)? onChange;
  final Function(int index, bool hasFocus)? onFocusChange;
  final bool enable;

  @override
  State<ListItemMileInput> createState() => _ListItemMileInputState();
}

class _ListItemMileInputState extends State<ListItemMileInput> {
  final TextStyle valueStyle = TextStyle(
    color: const Color(0xff969799),
    fontSize: 16.sp,
  );
  final TextStyle hintStyle = TextStyle(
    color: const Color(0xff969799),
    fontSize: 14.sp,
  );

  late TextEditingController startController = TextEditingController(text: (widget.startMile != null && widget.startMile! >= 0) ? "${widget.startMile}" : "")..addListener(_handleValueChange);

  late TextEditingController endController = TextEditingController(text: (widget.endMile != null && widget.endMile! >= 0) ? "${widget.endMile}".padLeft(3, "0") : "")..addListener(_handleValueChange);

  final FocusNode kNode = FocusNode();
  final FocusNode mileNode = FocusNode();

  @override
  void initState() {
    super.initState();
    kNode.addListener(_handleStartFocusChange);
    mileNode.addListener(_handleEndFocusChange);
  }

  @override
  void didUpdateWidget(ListItemMileInput oldWidget) {
    if (oldWidget.startMile != widget.startMile) {
      String text = (widget.startMile != null && widget.startMile! >= 0) ? "${widget.startMile}" : "";
      startController = TextEditingController(text: text)
        ..selection = TextSelection.fromPosition(TextPosition(offset: text.length))
        ..addListener(_handleValueChange);
    }
    if (oldWidget.endMile != widget.endMile) {
      String text = (widget.endMile != null && widget.endMile! >= 0) ? "${widget.endMile}".padLeft(3, "0") : "";
      endController = TextEditingController(text: text)
        ..selection = TextSelection.fromPosition(TextPosition(offset: text.length))
        ..addListener(_handleValueChange);
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        const Text(
          'K  ',
          style: TextStyle(color: Color(0xff323233)),
        ),
        Expanded(
          child: TextField(
            focusNode: kNode,
            maxLength: 10,
            enabled: widget.enable,
            controller: startController,
            keyboardType: TextInputType.number,
            decoration: InputDecoration(
              counterText: "",
              isDense: true,
              contentPadding: EdgeInsets.zero,
              border: InputBorder.none,
              hintMaxLines: 2,
              hintText: "请输入",
              hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 14.sp),
            ),
            style: TextStyle(color: const Color(0xff323233), fontSize: 16.sp),
          ),
        ),
        Text(
          '  +  ',
          style: valueStyle,
        ),
        Expanded(
          child: TextField(
            focusNode: mileNode,
            maxLength: 6,
            enabled: widget.enable,
            controller: endController,
            keyboardType: TextInputType.number,
            decoration: InputDecoration(
              isDense: true,
              counterText: "",
              contentPadding: EdgeInsets.zero,
              border: InputBorder.none,
              hintMaxLines: 2,
              hintText: "请输入",
              hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 14.sp),
            ),
            style: TextStyle(color: const Color(0xff323233), fontSize: 16.sp),
          ),
        ),
      ],
    );
  }

  @override
  void dispose() {
    super.dispose();
    startController.removeListener(_handleValueChange);
    startController.dispose();
    endController.removeListener(_handleValueChange);
    endController.dispose();
    kNode.removeListener(_handleStartFocusChange);
    kNode.dispose();
    mileNode.removeListener(_handleEndFocusChange);
    mileNode.dispose();
  }

  void _handleStartFocusChange() {
    widget.onFocusChange?.call(0, kNode.hasFocus);
  }

  void _handleEndFocusChange() {
    widget.onFocusChange?.call(1, mileNode.hasFocus);
  }

  void _handleValueChange() {
    if (endController.text.length > 3) {
      endController.text = endController.text.substring(endController.text.length - 3, endController.text.length);
      endController.selection = TextSelection.fromPosition(const TextPosition(offset: 3));
    }
    widget.onChange?.call(int.tryParse(startController.text), int.tryParse(endController.text));
  }
}

///路陪特殊需求，无需校验桩号
class ListItemMileInputExt extends StatefulWidget {
  const ListItemMileInputExt({Key? key, this.prefix, this.startMile, this.endMile, this.enable = true, this.onChange}) : super(key: key);
  final String? prefix;
  final int? startMile;
  final int? endMile;
  final Function(String? prefix, int? start, int? end)? onChange;
  final bool enable;

  @override
  State<ListItemMileInputExt> createState() => _ListItemMileInputStateExt();
}

class _ListItemMileInputStateExt extends State<ListItemMileInputExt> {
  final TextStyle valueStyle = TextStyle(
    color: const Color(0xff969799),
    fontSize: 16.sp,
  );
  final TextStyle hintStyle = TextStyle(
    color: const Color(0xff969799),
    fontSize: 14.sp,
  );

  late TextEditingController prefixController = TextEditingController(text: (widget.prefix != null && widget.prefix!.isNotEmpty) ? "${widget.prefix}" : "")..addListener(_handleValueChange);

  late TextEditingController startController = TextEditingController(text: (widget.startMile != null && widget.startMile! >= 0) ? "${widget.startMile}" : "")..addListener(_handleValueChange);

  late TextEditingController endController = TextEditingController(text: (widget.endMile != null && widget.endMile! >= 0) ? "${widget.endMile}" : "")..addListener(_handleValueChange);

  @override
  void didUpdateWidget(ListItemMileInputExt oldWidget) {
    if (oldWidget.prefix != widget.prefix) {
      String text = (widget.prefix != null && widget.prefix!.isNotEmpty) ? "${widget.prefix}" : "";
      prefixController = TextEditingController(text: text)
        ..selection = TextSelection.fromPosition(TextPosition(offset: text.length))
        ..addListener(_handleValueChange);
    }
    if (oldWidget.startMile != widget.startMile) {
      String text = (widget.startMile != null && widget.startMile! >= 0) ? "${widget.startMile}" : "";
      startController = TextEditingController(text: text)
        ..selection = TextSelection.fromPosition(TextPosition(offset: text.length))
        ..addListener(_handleValueChange);
    }
    if (oldWidget.endMile != widget.endMile) {
      String text = (widget.endMile != null && widget.endMile! >= 0) ? "${widget.endMile}" : "";
      endController = TextEditingController(text: text)
        ..selection = TextSelection.fromPosition(TextPosition(offset: text.length))
        ..addListener(_handleValueChange);
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Expanded(
          child: TextField(
            enabled: widget.enable,
            controller: prefixController,
            inputFormatters: [TLOnlyInputWorkFormatter()],
            decoration: InputDecoration(
              counterText: "",
              isDense: true,
              contentPadding: EdgeInsets.zero,
              border: InputBorder.none,
              hintMaxLines: 1,
              hintText: "请输字母",
              hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 14.sp),
            ),
            style: TextStyle(color: const Color(0xff323233), fontSize: 16.sp),
          ),
        ),
        Expanded(
          child: TextField(
            enabled: widget.enable,
            controller: startController,
            keyboardType: const TextInputType.numberWithOptions(decimal: true),
            inputFormatters: [
              //只允许输入小数
              FilteringTextInputFormatter.allow(RegExp("[0-9.]")),
              //FilteringTextInputFormatter.allow(RegExp("[0-9.]")),但这种限制会有问题，比如可以输入0.1.1这种其实就不是小数了，并且不能限制小数点的输入位数。
              TLNumberTextInputFormatter(),
            ],
            decoration: InputDecoration(
              counterText: "",
              isDense: true,
              contentPadding: EdgeInsets.zero,
              border: InputBorder.none,
              hintMaxLines: 2,
              hintText: "请输入",
              hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 14.sp),
            ),
            style: TextStyle(color: const Color(0xff323233), fontSize: 16.sp),
          ),
        ),
        Text(
          '  +  ',
          style: valueStyle,
        ),
        Expanded(
          child: TextField(
            enabled: widget.enable,
            controller: endController,
            keyboardType: const TextInputType.numberWithOptions(decimal: true),
            inputFormatters: [
              //只允许输入小数
              FilteringTextInputFormatter.allow(RegExp("[0-9.]")),
              //FilteringTextInputFormatter.allow(RegExp("[0-9.]")),但这种限制会有问题，比如可以输入0.1.1这种其实就不是小数了，并且不能限制小数点的输入位数。
              TLNumberTextInputFormatter(),
            ],
            decoration: InputDecoration(
              isDense: true,
              counterText: "",
              contentPadding: EdgeInsets.zero,
              border: InputBorder.none,
              hintMaxLines: 2,
              hintText: "请输入",
              hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 14.sp),
            ),
            style: TextStyle(color: const Color(0xff323233), fontSize: 16.sp),
          ),
        ),
      ],
    );
  }

  @override
  void dispose() {
    super.dispose();
    startController.removeListener(_handleValueChange);
    startController.dispose();
    endController.removeListener(_handleValueChange);
    endController.dispose();
  }

  void _handleValueChange() {
    widget.onChange?.call(prefixController.text, int.tryParse(startController.text), int.tryParse(endController.text));
  }
}

class ListItemLatLonInput extends StatefulWidget {
  const ListItemLatLonInput({Key? key, this.latitude, this.longitude, this.enable = true, this.onChange}) : super(key: key);
  final String? latitude;
  final String? longitude;
  final Function(String? longitude, String? latitude)? onChange;
  final bool enable;

  @override
  State<ListItemLatLonInput> createState() => _ListItemLatLonInputState();
}

class _ListItemLatLonInputState extends State<ListItemLatLonInput> {
  final TextStyle valueStyle = TextStyle(
    color: const Color(0xff969799),
    fontSize: 16.sp,
  );
  final TextStyle hintStyle = TextStyle(
    color: const Color(0xff969799),
    fontSize: 14.sp,
  );

  late TextEditingController longitudeController = TextEditingController(text: widget.longitude ?? "")..addListener(_handleValueChange);

  late TextEditingController latitudeController = TextEditingController(text: widget.latitude ?? "")..addListener(_handleValueChange);

  @override
  void initState() {
    super.initState();
  }

  @override
  void didUpdateWidget(ListItemLatLonInput oldWidget) {
    if (oldWidget.longitude != widget.longitude) {
      String text = widget.longitude ?? "";
      longitudeController = TextEditingController(text: text)
        ..selection = TextSelection.fromPosition(TextPosition(offset: text.length))
        ..addListener(_handleValueChange);
    }
    if (oldWidget.latitude != widget.latitude) {
      String text = widget.latitude ?? "";
      latitudeController = TextEditingController(text: text)
        ..selection = TextSelection.fromPosition(TextPosition(offset: text.length))
        ..addListener(_handleValueChange);
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Expanded(
          child: TextField(
            enabled: widget.enable,
            controller: longitudeController,
            keyboardType: const TextInputType.numberWithOptions(decimal: true),
            decoration: InputDecoration(
              isDense: true,
              contentPadding: EdgeInsets.zero,
              border: InputBorder.none,
              hintMaxLines: 2,
              hintText: "经度",
              hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 14.sp),
            ),
            style: TextStyle(color: const Color(0xff323233), fontSize: 16.sp),
          ),
        ),
        Text(
          '  ,  ',
          style: valueStyle,
        ),
        Expanded(
          child: TextField(
            enabled: widget.enable,
            controller: latitudeController,
            keyboardType: const TextInputType.numberWithOptions(decimal: true),
            decoration: InputDecoration(
              isDense: true,
              contentPadding: EdgeInsets.zero,
              border: InputBorder.none,
              hintMaxLines: 2,
              hintText: "纬度",
              hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 14.sp),
            ),
            style: TextStyle(color: const Color(0xff323233), fontSize: 16.sp),
          ),
        ),
      ],
    );
  }

  @override
  void dispose() {
    super.dispose();
    longitudeController.removeListener(_handleValueChange);
    longitudeController.dispose();
    latitudeController.removeListener(_handleValueChange);
    latitudeController.dispose();
  }

  void _handleValueChange() {
    widget.onChange?.call(longitudeController.text, latitudeController.text);
  }
}
