import 'package:flutter/material.dart';
import 'package:loading_more_list/loading_more_list.dart';
import 'package:tengits_common/widgets/src/loading_more_status_widget.dart';

class TLoadingMoreList<T> extends StatelessWidget {
  const TLoadingMoreList({
    Key? key,
    required this.itemBuilder,
    required this.sourceList,
    this.sliver = false,
    this.padding = EdgeInsets.zero,
    this.shrinkWrap = false,
    this.stateBuilder,
  }) : super(key: key);

  final Widget Function(BuildContext context, T item, int index, bool isLast) itemBuilder;
  final LoadingMoreBase<T> sourceList;
  final bool sliver;
  final EdgeInsets padding;
  final bool shrinkWrap;
  final Widget? Function(BuildContext context, IndicatorStatus status, LoadingMoreBase listSource, bool isSliver)? stateBuilder;

  @override
  Widget build(BuildContext context) {
    return sliver ? _buildSliverList() : _buildList();
  }

  Widget _buildList() {
    return LoadingMoreList<T>(
      ListConfig<T>(
          itemBuilder: ((context, item, index) => itemBuilder(context, item, index, (index + 1) >= sourceList.length)),
          sourceList: sourceList,
          indicatorBuilder: (BuildContext context, IndicatorStatus status) {
            return stateBuilder?.call(context, status, sourceList, sliver) ?? buildLoadingMoreListIndicator(context, status, sourceList);
          },
          padding: padding,
          lastChildLayoutType: LastChildLayoutType.fullCrossAxisExtent,
          autoRefresh: true,
          shrinkWrap: shrinkWrap),
    );
  }

  Widget _buildSliverList() {
    return LoadingMoreSliverList<T>(
      SliverListConfig<T>(
          itemBuilder: ((context, item, index) => itemBuilder(context, item, index, (index + 1) >= sourceList.length)),
          sourceList: sourceList,
          indicatorBuilder: (BuildContext context, IndicatorStatus status) {
            return stateBuilder?.call(context, status, sourceList, sliver) ?? buildLoadingMoreListIndicator(context, status, sourceList, true);
          },
          padding: padding,
          lastChildLayoutType: LastChildLayoutType.fullCrossAxisExtent,
          autoRefresh: true),
    );
  }
}
