import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import 'tab_bar_indicator.dart';

class TLTabBar extends StatelessWidget {
  const TLTabBar({
    Key? key,
    required this.tabController,
    required this.tabDatas,
    this.onTap,
  }) : super(key: key);

  final TabController tabController;
  final List tabDatas;
  final ValueChanged<int>? onTap;

  @override
  Widget build(BuildContext context) {
    return _tabBar();
  }

  TabBar _tabBar() {
    return TabBar(
      tabs: _tabs(),
      controller: tabController,
      isScrollable: false,
      physics: const NeverScrollableScrollPhysics(),
      labelStyle: TextStyle(
        fontSize: 24.sp,
        fontWeight: FontWeight.w500,
      ),
      labelColor: Colors.white,
      labelPadding: EdgeInsets.zero,
      unselectedLabelColor: const Color(0xFFEBEDF0),
      unselectedLabelStyle: TextStyle(
        fontSize: 16.sp,
        fontWeight: FontWeight.w400,
      ),
      indicator: TUnderlineTabIndicator(
        borderSide: BorderSide(
          color: Colors.white,
          width: 4.w,
        ),
      ),
      onTap: onTap,
    );
  }

  List<Widget> _tabs() {
    List<Widget> tabList = [];
    for (var tabData in tabDatas) {
      tabList.add(
        Tab(text: tabData["text"]),
      );
    }
    return tabList;
  }
}

class TLTabBarView extends StatelessWidget {
  const TLTabBarView({
    Key? key,
    required this.tabController,
    required this.tabDatas,
    required this.children,
  }) : super(key: key);

  final TabController tabController;
  final List tabDatas;
  final List<Widget> Function() children;

  @override
  Widget build(BuildContext context) {
    return _tabBarView();
  }

  TabBarView _tabBarView() {
    return TabBarView(
      children: children.call(),
      controller: tabController,
    );
  }
}
