// ignore_for_file: file_names

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/utils/src/image_utils.dart';

import 'triangel_shape.dart';

class RedTextLabel extends StatelessWidget {
  const RedTextLabel(this.data, {Key? key, this.isRequired = false}) : super(key: key);

  final String? data;
  final bool isRequired;

  @override
  Widget build(BuildContext context) {
    return RichText(
        text: TextSpan(children: [
      TextSpan(text: '*', style: isRequired ? TextStyle(color: Colors.red, fontSize: 16.sp, fontWeight: FontWeight.w400) : const TextStyle(color: Colors.transparent)),
      TextSpan(text: data, style: TextStyle(color: const Color(0xFF646566), fontSize: 16.sp, fontWeight: FontWeight.w400)),
    ]));
  }
}

class TextFlag<T> extends StatelessWidget {
  const TextFlag({
    Key? key,
    required this.title,
    this.style,
    this.maxLines = 1,
    this.overflow = TextOverflow.ellipsis,
    this.imageWidth,
    this.imageHeight,
    this.isRequired = false,
    this.trailing,
  }) : super(key: key);

  final T title;
  final TextStyle? style;
  final int maxLines;
  final TextOverflow overflow;
  final double? imageWidth;
  final double? imageHeight;
  final bool isRequired;
  final Widget? trailing;

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.topLeft,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Image(
            image: ImageUtils.getAssetImage("assets/images/path.png", package: "tengits_common"),
            width: imageWidth ?? 7.w,
            height: imageHeight ?? 23.h,
            fit: BoxFit.fill,
          ),
          SizedBox(
            width: 8.w,
          ),
          Expanded(
            child: title is String ? RichText(
              text: TextSpan(children: [
                TextSpan(
                    text: '*',
                    style: isRequired
                        ? TextStyle(color: Colors.red, fontSize: 16.sp)
                        : const TextStyle(
                            color: Colors.transparent,
                          )),
                TextSpan(
                  text: title as String,
                  style: style ??
                      TextStyle(
                        color: const Color(0xFF323233),
                        fontSize: 16.sp,
                        fontWeight: FontWeight.w500,
                      ),
                ),
              ]),
              maxLines: maxLines,
              overflow: overflow,
              textAlign: TextAlign.left,
            ) : title as Widget,
          ),
          SizedBox(
            width: 8.w,
          ),
          trailing ?? const SizedBox.shrink(),
        ],
      ),
    );
  }
}

class PositionedImageFlag extends StatelessWidget {
  const PositionedImageFlag({Key? key, this.imagePath}) : super(key: key);

  final String? imagePath;

  @override
  Widget build(BuildContext context) {
    if (imagePath != null) {
      return Positioned(
        child: Image(
          image: ImageUtils.getAssetImage(imagePath!),
          width: 72.w,
          height: 66.h,
          fit: BoxFit.fill,
        ),
        right: 8.w,
        bottom: 24.h,
      );
    } else {
      return const SizedBox.shrink();
    }
  }
}

class CardContainer extends Container {
  CardContainer({Key? key, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Widget? child})
      : super(
            key: key,
            margin: margin ?? EdgeInsets.only(bottom: 16.h),
            padding: padding ?? EdgeInsets.only(top: 24.h, bottom: 8.h),
            decoration: BoxDecoration(color: Colors.white, borderRadius: BorderRadius.circular(8.r)),
            child: child);
}

class SeparationLine extends Container {
  SeparationLine({Key? key, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, double? width, double? height, Color? color})
      : super(
          key: key,
          margin: margin,
          padding: padding,
          width: width,
          height: height ?? 1.h,
          color: color ?? const Color(0xFFF7F8FA),
        );
}

class BottomButtonMenu extends StatelessWidget {
  const BottomButtonMenu({Key? key, required this.bottomMenus, this.onPopupMenuTap}) : super(key: key);

  final List bottomMenus;
  final Function(dynamic)? onPopupMenuTap;

  @override
  Widget build(BuildContext context) {
    List<PopupMenuEntry> moreMenus = [];
    for (var i = 0; i < bottomMenus.length; i++) {
      if (i == 0) {
        continue;
      }
      moreMenus.add(PopupMenuItem(
          value: bottomMenus[i]["value"],
          child: Center(
            child: Text(
              bottomMenus[i]["text"],
              style: TextStyle(color: const Color(0xFF222222), fontSize: 16.sp, fontWeight: FontWeight.w400),
            ),
          )));
    }
    //
    if (bottomMenus.length > 2) {
      return Column(
        children: [
          SeparationLine(
            margin: EdgeInsets.only(top: 16.h),
            color: const Color(0xFFEBEDF0),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Expanded(
                child: PopupMenuButton(
                  child: Text(
                    "更多",
                    style: TextStyle(color: const Color(0xFF969799), fontSize: 16.sp, fontWeight: FontWeight.w400),
                    textAlign: TextAlign.center,
                  ),
                  offset: const Offset(0, 35),
                  shape: const TriangleShape(),
                  itemBuilder: (context) {
                    return moreMenus;
                  },
                  onSelected: onPopupMenuTap,
                ),
              ),
              SeparationLine(
                width: 1.w,
                height: 24.h,
                color: const Color(0xFFEBEDF0),
              ),
              Expanded(
                child: TextButton(
                    onPressed: () {
                      onPopupMenuTap?.call(bottomMenus.first["value"]);
                    },
                    child: Text(
                      bottomMenus.first["text"],
                      style: TextStyle(color: const Color(0xFF2B6BD8), fontSize: 16.sp, fontWeight: FontWeight.w400),
                      textAlign: TextAlign.center,
                    )),
              )
            ],
          )
        ],
      );
    } else if (bottomMenus.length == 2) {
      return Column(
        children: [
          SeparationLine(
            margin: EdgeInsets.only(top: 16.h),
            color: const Color(0xFFEBEDF0),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Expanded(
                child: TextButton(
                    onPressed: () {
                      onPopupMenuTap?.call(bottomMenus.last["value"]);
                    },
                    child: Text(
                      bottomMenus.last["text"],
                      style: TextStyle(color: const Color(0xFF2B6BD8), fontSize: 16.sp, fontWeight: FontWeight.w400),
                      textAlign: TextAlign.center,
                    )),
              ),
              SeparationLine(
                width: 1.w,
                height: 24.h,
                color: const Color(0xFFEBEDF0),
              ),
              Expanded(
                child: TextButton(
                    onPressed: () {
                      onPopupMenuTap?.call(bottomMenus.first["value"]);
                    },
                    child: Text(
                      bottomMenus.first["text"],
                      style: TextStyle(color: const Color(0xFF2B6BD8), fontSize: 16.sp, fontWeight: FontWeight.w400),
                      textAlign: TextAlign.center,
                    )),
              )
            ],
          )
        ],
      );
    } else if (bottomMenus.length == 1) {
      return Column(
        children: [
          SeparationLine(
            margin: EdgeInsets.only(top: 16.h),
            color: const Color(0xFFEBEDF0),
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Expanded(
                child: TextButton(
                    onPressed: () {
                      onPopupMenuTap?.call(bottomMenus.first["value"]);
                    },
                    child: Text(
                      bottomMenus.first["text"],
                      style: TextStyle(color: const Color(0xFF2B6BD8), fontSize: 16.sp, fontWeight: FontWeight.w400),
                      textAlign: TextAlign.center,
                    )),
              ),
            ],
          )
        ],
      );
    } else {
      return SeparationLine(
        margin: EdgeInsets.only(top: 16.h),
        color: const Color(0xFFFFFFFF),
      );
    }
  }
}
