import 'package:flutter/material.dart';

class TriangleShape extends ShapeBorder {

  const TriangleShape();

  final BorderSide _side = BorderSide.none;
  final BorderRadiusGeometry _borderRadius = BorderRadius.zero;

  @override
  EdgeInsetsGeometry get dimensions => EdgeInsets.all(_side.width);

  @override
  Path getInnerPath(
    Rect rect, {
    TextDirection? textDirection,
  }) {

    final Path path = Path();

    path.addRRect(
      _borderRadius.resolve(textDirection).toRRect(rect).deflate(_side.width),
    );

    return path;
  }

  @override
  Path getOuterPath(Rect rect, {TextDirection? textDirection}) {

    final Path path = Path();
    final RRect rrect = _borderRadius.resolve(textDirection).toRRect(rect);

    path.moveTo(0, 4);
    path.quadraticBezierTo(0, 0, 4, 0);
    path.lineTo(rrect.width - 30, 0);
    path.lineTo(rrect.width - 20, -10);
    path.lineTo(rrect.width - 10, 0);
    path.lineTo(rrect.width - 4, 0);
    path.quadraticBezierTo(rrect.width, 0, rrect.width, 4);
    path.lineTo(rrect.width, rrect.height - 4);
    path.quadraticBezierTo(rrect.width, rrect.height, rrect.width - 4, rrect.height);
    path.lineTo(4, rrect.height);
    path.quadraticBezierTo(0, rrect.height, 0, rrect.height - 4);

    return path;
  }

  @override
  void paint(Canvas canvas, Rect rect, {TextDirection? textDirection}) {}

  @override
  ShapeBorder scale(double t) => RoundedRectangleBorder(
    side: _side.scale(t),
    borderRadius: _borderRadius * t,
  );
}
